@@ -1,6 +1,5 @@
 /*=============================================================================
 XMOTO
-Copyright (C) 2005-2006 Rasmus Neckelmann (neckelmann@gmail.com)
 
 This file is part of XMOTO.
 
@@ -36,8 +35,6 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 #define REFLECT_REMAINDER(X)	((unsigned int) _ReflectCRC32((X), WIDTH))
 
-namespace vapp {
-
   /*===========================================================================
   Global data
   ===========================================================================*/
@@ -102,5 +99,3 @@ namespace vapp {
     
     return nReflection;
   }  
-
-}
