@@ -1,6 +1,5 @@
 /*=============================================================================
 XMOTO
-Copyright (C) 2005-2006 Rasmus Neckelmann (neckelmann@gmail.com)
 
 This file is part of XMOTO.
 
@@ -24,9 +23,8 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 #include "GameText.h"
 #include "VXml.h"
-#include "GUI.h"
-
-namespace vapp {
+#include "gui/basic/GUI.h"
+#include "drawlib/DrawLib.h"
 
   /*===========================================================================
   Clearing
@@ -52,8 +50,8 @@ namespace vapp {
 
     setFont(m_drawLib->getFontSmall());    
     putText(40,64,std::string(GAMETEXT_ALLRECORDS) + ": ");
-    for(int i=0;i<m_Col1.size();i++) {
-      if(i == m_nHighlight1) {
+    for(unsigned int i=0;i<m_Col1.size();i++) {
+      if(m_nHighlight1 >=0 && i == (unsigned int)m_nHighlight1) {
         setTextSolidColor(MAKE_COLOR(255,255,0,255));
       }
       putText(30,90+i*16,m_Col1[i]);
@@ -62,8 +60,8 @@ namespace vapp {
     }
 
     putText(40,100 + 16*m_Col1.size(),std::string(GAMETEXT_PERSONALRECORDS) + ":");
-    for(int i=0;i<m_Col3.size();i++) {
-      if(i == m_nHighlight2) {
+    for(unsigned int i=0;i<m_Col3.size();i++) {
+      if(m_nHighlight2 >=0 && i == (unsigned int)m_nHighlight2) {
         setTextSolidColor(MAKE_COLOR(255,255,0,255));
       }
       putText(30,126+i*16 + 16*m_Col1.size(),m_Col3[i]);
@@ -73,6 +71,3 @@ namespace vapp {
     
     setFont(pOldFont);
   }
-
-}
-
