@@ -242,7 +242,9 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   } 
   
   void MGE_PlayerDies::doAction(Scene *p_pScene) {
-    p_pScene->killPlayer(m_player);
+    if(((int)p_pScene->Players().size()) > m_player) { // action are from external data (replays, network, so basically, not sure)
+      p_pScene->killPlayer(m_player);
+    }
   }
 
   void MGE_PlayerDies::serialize(DBuffer &Buffer) {
@@ -265,6 +267,46 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
     return "Player " + v_txt_player.str() + " dies";
   }
 
+  //////////////////////////////
+  MGE_PlayerWins::MGE_PlayerWins(int p_eventTime) 
+  : SceneEvent(p_eventTime) {
+    m_player = 0;
+  }
+
+  MGE_PlayerWins::MGE_PlayerWins(int p_eventTime, int i_player) 
+    : SceneEvent(p_eventTime) {
+      m_player = i_player;
+  }
+
+  MGE_PlayerWins::~MGE_PlayerWins() {
+  } 
+  
+  void MGE_PlayerWins::doAction(Scene *p_pScene) {
+    if(((int)p_pScene->Players().size()) > m_player) { // action are from external data (replays, network, so basically, not sure)
+      p_pScene->makePlayerWin(m_player);
+    }
+  }
+
+  void MGE_PlayerWins::serialize(DBuffer &Buffer) {
+  }
+  
+  void MGE_PlayerWins::unserialize(DBuffer &Buffer) {
+  }
+
+  GameEventType MGE_PlayerWins::SgetType() {
+    return GAME_EVENT_PLAYER_WINS;
+  }
+
+  GameEventType MGE_PlayerWins::getType() {
+    return SgetType();
+  }
+
+  std::string MGE_PlayerWins::toString() {
+    std::ostringstream v_txt_player;
+    v_txt_player << m_player;
+    return "Player " + v_txt_player.str() + " wins";
+  }
+
   //////////////////////////////
   MGE_PlayersEnterZone::MGE_PlayersEnterZone(int p_eventTime) 
     : SceneEvent(p_eventTime) {
@@ -400,7 +442,9 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   } 
   
   void MGE_PlayerLeavesZone::doAction(Scene *p_pScene) {
-    p_pScene->playerLeavesZone(m_player, m_zone);
+    if(((int)p_pScene->Players().size()) > m_player) { // action are from external data (replays, network, so basically, not sure)
+      p_pScene->playerLeavesZone(m_player, m_zone);
+    }
   }
 
   void MGE_PlayerLeavesZone::serialize(DBuffer &Buffer) {
@@ -483,7 +527,9 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   } 
   
   void MGE_PlayerTouchesEntity::doAction(Scene *p_pScene) {
-    p_pScene->playerTouchesEntity(m_player, m_entityID, m_bTouchedWithHead);
+    if(((int)p_pScene->Players().size()) > m_player) { // action are from external data (replays, network, so basically, not sure)
+      p_pScene->playerTouchesEntity(m_player, m_entityID, m_bTouchedWithHead);
+    }
   }
 
   void MGE_PlayerTouchesEntity::serialize(DBuffer &Buffer) {
@@ -511,21 +557,23 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   MGE_EntityDestroyed::MGE_EntityDestroyed(int p_eventTime) 
   : SceneEvent(p_eventTime) {
     m_entitySize = 0.0;
+    m_takenByPlayer = -1; // unknown
   }
 
-  MGE_EntityDestroyed::MGE_EntityDestroyed(int p_eventTime, std::string i_entityId, EntitySpeciality i_entityType, Vector2f i_entityPosition, float i_entitySize)
+  MGE_EntityDestroyed::MGE_EntityDestroyed(int p_eventTime, std::string i_entityId, EntitySpeciality i_entityType, Vector2f i_entityPosition, float i_entitySize, int i_takenByPlayer)
     : SceneEvent(p_eventTime) {
       m_entityId       = i_entityId;
       m_entityType     = i_entityType;
       m_entityPosition = i_entityPosition;
       m_entitySize     = i_entitySize;
+      m_takenByPlayer  = i_takenByPlayer;
     }
 
   MGE_EntityDestroyed::~MGE_EntityDestroyed() {
   }
   
   void MGE_EntityDestroyed::doAction(Scene *p_pScene) {
-    p_pScene->entityDestroyed(m_entityId, m_eventTime);
+    p_pScene->entityDestroyed(m_entityId, m_eventTime, m_takenByPlayer);
   }
 
   void MGE_EntityDestroyed::serialize(DBuffer &Buffer) {
@@ -586,6 +634,10 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
     return m_entityId;
   }
 
+  int MGE_EntityDestroyed::takenByPlayer() {
+    return m_takenByPlayer;
+  }
+
   //////////////////////////////
   MGE_ClearMessages::MGE_ClearMessages(int p_eventTime) 
   : SceneEvent(p_eventTime) {
@@ -1002,7 +1054,9 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   } 
   
   void MGE_SetPlayerPosition::doAction(Scene *p_pScene) {
-    p_pScene->setPlayerPosition(m_player, m_x, m_y, m_bRight);
+    if(((int)p_pScene->Players().size()) > m_player) { // action are from external data (replays, network, so basically, not sure)
+      p_pScene->setPlayerPosition(m_player, m_x, m_y, m_bRight);
+    }
   }
 
   void MGE_SetPlayerPosition::serialize(DBuffer &Buffer) {
@@ -2093,7 +2147,9 @@ std::string MGE_SetPhysicsBlockTranslation::toString()
   } 
   
   void MGE_AddForceToPlayer::doAction(Scene *p_pScene) {
-    p_pScene->addForceToPlayer(m_player, m_force, m_startTime, m_endTime);
+    if(((int)p_pScene->Players().size()) > m_player) { // action are from external data (replays, network, so basically, not sure)
+      p_pScene->addForceToPlayer(m_player, m_force, m_startTime, m_endTime);
+    }
   }
 
   void MGE_AddForceToPlayer::serialize(DBuffer &Buffer) {
