@@ -76,7 +76,8 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
     /*           = 40, */
     GAME_EVENT_SETPHYSICSBLOCKSELFROTATION  = 41,
     GAME_EVENT_SETPHYSICSBLOCKTRANSLATION   = 42,
-		GAME_EVENT_CAMERASETPOS                 = 43
+    GAME_EVENT_CAMERASETPOS                 = 43,
+    GAME_EVENT_PLAYER_WINS                  = 44
   };
 
 class SceneEvent;
@@ -145,6 +146,24 @@ class MGE_PlayerDies : public SceneEvent {
   int  m_player;
 };
 
+class MGE_PlayerWins : public SceneEvent {
+ public:
+  MGE_PlayerWins(int p_eventTime);
+  MGE_PlayerWins(int p_eventTime, int i_player);
+  ~MGE_PlayerWins();
+
+  void doAction(Scene *p_pScene);
+  void serialize(DBuffer &Buffer);
+  void unserialize(DBuffer &Buffer);
+  static GameEventType SgetType();
+  GameEventType getType();
+
+  std::string toString();
+
+ private:
+  int  m_player;
+};
+
 class MGE_PlayersEnterZone : public SceneEvent {
  public:
   MGE_PlayersEnterZone(int p_eventTime);
@@ -261,7 +280,7 @@ class MGE_PlayerTouchesEntity : public SceneEvent {
 class MGE_EntityDestroyed : public SceneEvent {
  public:
   MGE_EntityDestroyed(int p_eventTime);
-  MGE_EntityDestroyed(int p_eventTime, std::string i_entityId, EntitySpeciality i_entityType, Vector2f i_entityPosition, float i_entitySize);
+  MGE_EntityDestroyed(int p_eventTime, std::string i_entityId, EntitySpeciality i_entityType, Vector2f i_entityPosition, float i_entitySize, int i_takenByPlayer /* -1 if taken by an external event */);
   ~MGE_EntityDestroyed();
 
   void doAction(Scene *p_pScene);
@@ -274,12 +293,14 @@ class MGE_EntityDestroyed : public SceneEvent {
   std::string toString();
 
   std::string EntityId();
+  int takenByPlayer(); // -1 if taken by an external event
 
  private:
   std::string m_entityId;
   EntitySpeciality m_entityType;
   Vector2f    m_entityPosition;
   float       m_entitySize;
+  int         m_takenByPlayer; // -1 if taken by an external event
 };
 
 class MGE_ClearMessages : public SceneEvent {
