@@ -22,6 +22,8 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #define __IMAGE_H__
 
 #include "VCommon.h"
+#include "helpers/Color.h"
+#include <string>
 
 /*===========================================================================
   Lazy stuff
