@@ -24,18 +24,21 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "xmscene/Level.h"
 #include "xmscene/Entity.h"
 #include "xmscene/Block.h"
+#include "chipmunk/chipmunk.h"
 
 SDynamicObject::SDynamicObject(int p_startTime, int p_endTime, int pPeriod) {
   m_time = 0;
   m_startTime = p_startTime;
   m_endTime   = p_endTime;
   m_period    = pPeriod;
+
+  m_objectId  = "";
 }
 
 SDynamicObject::~SDynamicObject() {
 }
 
-bool SDynamicObject::nextState(MotoGame* v_motoGame, int i_nbCents) {
+bool SDynamicObject::nextState(Scene* v_motoGame, int i_nbCents) {
   int v_realNbCents;
 
   v_realNbCents = i_nbCents;
@@ -70,7 +73,40 @@ int SDynamicObject::Period() const {
   return m_period;
 }
 
-void SDynamicTranslation::performXY(float *vx, float *vy) {
+
+
+SDynamicTranslation::SDynamicTranslation(float pX, float pY, int pPeriod) 
+{
+  float Z;
+
+  m_X     = pX;
+  m_Y     = pY;
+
+  m_sensUp = true;
+  Z      = sqrt(m_X * m_X + m_Y * m_Y);
+
+  m_Speed  = 0.0;
+  if(pPeriod != 0) {
+    m_Speed  = (Z * 2) / ((float)(pPeriod));
+  }
+
+  m_moveX = 0.0;
+  m_moveY = 0.0;
+  if(Z != 0.0) {
+    m_moveX  = (m_Speed * m_X) / Z;
+    m_moveY  = (m_Speed * m_Y) / Z;
+  }
+
+  m_totalMoveX = 0.0;
+  m_totalMoveY = 0.0;
+}
+
+SDynamicTranslation::~SDynamicTranslation() 
+{
+}
+
+void SDynamicTranslation::performXY(float *vx, float *vy) 
+{
   *vx = m_sensUp ? m_moveX : -m_moveX;
   *vy = m_sensUp ? m_moveY : -m_moveY;
 
@@ -85,8 +121,10 @@ void SDynamicTranslation::performXY(float *vx, float *vy) {
   }
 }
 
-SDynamicRotation::SDynamicRotation(float pInitAngle, float pRadius, int
-pPeriod) {
+
+
+SDynamicRotation::SDynamicRotation(float pInitAngle, float pRadius, int pPeriod) 
+{
   m_Speed = 0.0;
   if(pPeriod != 0) {
     m_Speed = (2 * M_PI) / ((float)(pPeriod));
@@ -104,34 +142,6 @@ pPeriod) {
 SDynamicRotation::~SDynamicRotation() {
 }
 
-SDynamicTranslation::SDynamicTranslation(float pX, float pY, int pPeriod) {
-  float m_Z;
-
-  m_X     = pX;
-  m_Y     = pY;
-
-  m_sensUp = true;
-  m_Z      = sqrt(m_X * m_X + m_Y * m_Y);
-
-  m_Speed  = 0.0;
-  if(pPeriod != 0) {
-    m_Speed  = (m_Z * 2) / ((float)(pPeriod));
-  }
-
-  m_moveX = 0.0;
-  m_moveY = 0.0;
-  if(m_Z != 0.0) {
-    m_moveX  = (m_Speed * m_X) / m_Z;
-    m_moveY  = (m_Speed * m_Y) / m_Z;
-  }
-
-  m_totalMoveX = 0.0;
-  m_totalMoveY = 0.0;
-}
-
-SDynamicTranslation::~SDynamicTranslation() {
-}
-
 void SDynamicRotation::performXY(float *vx, float *vy) {
   if(m_Angle >= 2 * M_PI) {m_Angle -= 2 * M_PI;} /* because of float limit */
   float x,y;
@@ -146,6 +156,8 @@ void SDynamicRotation::performXY(float *vx, float *vy) {
   m_Angle += m_Speed;
 }
 
+
+
 SDynamicSelfRotation::SDynamicSelfRotation(int i_period) {
   m_period = i_period;
   m_totalAngle = 0.0;
@@ -170,20 +182,29 @@ void SDynamicSelfRotation::performXY(float *vAngle) {
   }
 }
 
+
+
+
+
 /* entity */
 
 SDynamicEntityMove::SDynamicEntityMove(std::string pEntity, int p_startTime, int p_endTime, int pPeriod) : SDynamicObject(p_startTime, p_endTime, pPeriod){
-  m_entity = pEntity;
+  m_entityName = pEntity;
+  m_objectId   = pEntity;
+  m_entity     = NULL;
 }
 
 SDynamicEntityMove::~SDynamicEntityMove() {
 }
 
-void SDynamicEntityMove::performMove(MotoGame* v_motoGame, int i_nbCents) {
-  Entity* p = v_motoGame->getLevelSrc()->getEntityById(m_entity);
-  if(! p->isAlive()){
+void SDynamicEntityMove::performMove(Scene* v_motoGame, int i_nbCents) {
+  if(m_entity == NULL)
+    m_entity = v_motoGame->getLevelSrc()->getEntityById(m_entityName);
+
+  if(m_entity->isAlive() == false){
     return;
   }
+
   float vx, vy, vAngle;
   float addvx = 0.0, addvy = 0.0, addvAngle = 0.0;
 
@@ -195,22 +216,17 @@ void SDynamicEntityMove::performMove(MotoGame* v_motoGame, int i_nbCents) {
       addvAngle = vAngle;
     }
 
-    if(addvx != 0.0 || addvy != 0) { /* a simple fast test because it's probably the main case */
-      v_motoGame->SetEntityPos(p,
-			       addvx + p->DynamicPosition().x,
-			       addvy + p->DynamicPosition().y);
+    /* a simple fast test because it's probably the main case */
+    if(addvx != 0.0 || addvy != 0) { 
+      v_motoGame->translateEntity(m_entity, addvx, addvy);
     }
 
-    if(vAngle != 0.0) { /* a simple fast test because it's probably the main case */
-      v_motoGame->SetEntityDrawAngle(p->Id(), addvAngle + p->DrawAngle());
-    }
+    /* a simple fast test because it's probably the main case */
+    if(vAngle != 0.0)
+      m_entity->setDrawAngle(addvAngle + m_entity->DrawAngle());
   }
 }
 
-std::string SDynamicEntityMove::getObjectId() {
-  return m_entity;
-}
-
 SDynamicEntityRotation::SDynamicEntityRotation(std::string pEntity, float pInitAngle, float pRadius, int pPeriod, int p_startTime, int p_endTime)
   : SDynamicEntityMove(pEntity, p_startTime, p_endTime, pPeriod), SDynamicRotation(pInitAngle, pRadius, pPeriod) {
 }
@@ -236,15 +252,20 @@ void SDynamicEntityTranslation::performXY(float *vx, float *vy, float *vAngle) {
 
 /* block */
 
-SDynamicBlockMove::SDynamicBlockMove(std::string pBlock, int p_startTime, int p_endTime, int pPeriod) : SDynamicObject(p_startTime, p_endTime, pPeriod){
-  m_block = pBlock;
+SDynamicBlockMove::SDynamicBlockMove(std::string pBlock, int p_startTime, int p_endTime, int pPeriod)
+  : SDynamicObject(p_startTime, p_endTime, pPeriod){
+  m_blockName = pBlock;
+  m_objectId  = pBlock;
+  m_block     = NULL;
 }
 
 SDynamicBlockMove::~SDynamicBlockMove() {
 }
 
-void SDynamicBlockMove::performMove(MotoGame* v_motoGame, int i_nbCents) {
-  Block *p = v_motoGame->getLevelSrc()->getBlockById(m_block);
+void SDynamicBlockMove::performMove(Scene* v_motoGame, int i_nbCents) {
+  if(m_block == NULL)
+    m_block = v_motoGame->getLevelSrc()->getBlockById(m_blockName);
+  
   float vx, vy, vAngle;
   float addvx = 0.0, addvy = 0.0, addvAngle = 0.0;
 
@@ -256,22 +277,14 @@ void SDynamicBlockMove::performMove(MotoGame* v_motoGame, int i_nbCents) {
       addvAngle = vAngle;
     }
 
-    if(addvx != 0.0 || addvy != 0) { /* a simple fast test because it's probably the main case */
-      v_motoGame->MoveBlock(p->Id(),
-			    addvx,
-			    addvy);
-    }
+    if(addvx != 0.0 || addvy != 0)
+      v_motoGame->MoveBlock(m_block, addvx, addvy);
 
-    if(vAngle != 0.0) { /* a simple fast test because it's probably the main case */
-      v_motoGame->SetBlockRotation(p->Id(), addvAngle + p->DynamicRotation());
-    }
+    if(vAngle != 0.0)
+      v_motoGame->SetBlockRotation(m_block, addvAngle + m_block->DynamicRotation());
   }
 }
 
-std::string SDynamicBlockMove::getObjectId() {
-  return m_block;
-}
-
 SDynamicBlockRotation::SDynamicBlockRotation(std::string pBlock, float pInitAngle, float pRadius, int pPeriod, int p_startTime, int p_endTime) : SDynamicBlockMove(pBlock, p_startTime, p_endTime, pPeriod), SDynamicRotation(pInitAngle, pRadius, pPeriod) {
 }
 
@@ -319,3 +332,98 @@ void SDynamicEntitySelfRotation::performXY(float *vx, float *vy, float *vAngle)
   *vx = *vy = 0.0;
   SDynamicSelfRotation::performXY(vAngle);
 }
+
+
+
+SPhysicBlockMove::SPhysicBlockMove(std::string blockName, int startTime, int endTime, int period)
+  : SDynamicObject(startTime, endTime, period)
+{
+  m_blockName = blockName;
+  m_objectId  = blockName;
+  m_block     = NULL;
+}
+
+void SPhysicBlockMove::performMove(Scene* pScene, int i_nbCents)
+{
+  if(m_block == NULL)
+    m_block = pScene->getLevelSrc()->getBlockById(m_blockName);
+  
+  if(i_nbCents > 0) {
+    for(int i=0; i<i_nbCents; i++) {
+      applyForce();
+    }
+  }
+}
+
+SPhysicBlockSelfRotation::SPhysicBlockSelfRotation(std::string blockName, int startTime, int endTime, int torque)
+  : SPhysicBlockMove(blockName, startTime, endTime, 1)
+{
+  m_torque = torque;
+}
+
+void SPhysicBlockSelfRotation::applyForce()
+{
+  // magical formula to change the asked period into a force
+  cpBody* body = m_block->getPhysicBody();
+  if(body == NULL)
+    return;
+
+  // in the moon buggy example, the author manually update
+  // the torque instead of using applyforce, let's do the same
+  body->t += m_torque;
+}
+
+SPhysicBlockTranslation::SPhysicBlockTranslation(std::string blockName,
+						 float x, float y,
+						 int period,
+						 int startTime, int endTime)
+  : SPhysicBlockMove(blockName, startTime, endTime, period)
+{
+  float Z;
+
+  m_X     = x;
+  m_Y     = y;
+
+  m_sensUp = true;
+  Z        = sqrt(m_X*m_X + m_Y*m_Y);
+
+  m_Speed  = 0.0;
+  if(period != 0) {
+    m_Speed  = (Z * 2) / ((float)(period));
+  }
+
+  m_moveX = 0.0;
+  m_moveY = 0.0;
+  if(Z != 0.0) {
+    m_moveX  = (m_Speed * m_X) / Z;
+    m_moveY  = (m_Speed * m_Y) / Z;
+  }
+
+  m_totalMoveX = 0.0;
+  m_totalMoveY = 0.0;
+}
+
+void SPhysicBlockTranslation::applyForce()
+{
+  cpBody* body = m_block->getPhysicBody();
+  if(body == NULL)
+    return;
+
+  float x = m_sensUp ? m_moveX : -m_moveX;
+  float y = m_sensUp ? m_moveY : -m_moveY;
+
+  m_totalMoveX += m_sensUp ? fabs(x) : -fabs(x);
+  m_totalMoveY += m_sensUp ? fabs(y) : -fabs(y);
+
+  if(
+     (m_totalMoveX < 0 || m_totalMoveX > fabs(m_X)) ||
+     (m_totalMoveY < 0 || m_totalMoveY > fabs(m_Y))
+     ) {
+    m_sensUp = !m_sensUp;
+  }
+
+  // apply a force so that the blocks moves of (x,y)
+  // TODO::this mult need tweaking
+  float mult = 25000.0f;
+  cpBodyApplyForce(body, cpv(x*mult, y*mult), cpvzero);
+}
