@@ -32,9 +32,23 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 /* Some places #define _T, which we want for a template parameter */
 #undef _T
 
-#if !defined(XMOTO_LITTLE_ENDIAN) && !defined(XMOTO_BIG_ENDIAN)
-  /* Assume little endian */
-  #define XMOTO_LITTLE_ENDIAN 1
+#ifdef HAVE_LIBKERN_OSBYTEORDER_H
+  /* Configure's endian test is no good for universal binaries, instead
+   * use the OS X header. */
+  #undef XMOTO_LITTLE_ENDIAN
+  #undef XMOTO_BIG_ENDIAN
+  #include <libkern/OSByteOrder.h>
+  #ifdef __BIG_ENDIAN__
+    #define XMOTO_BIG_ENDIAN 1
+  #else
+    #define XMOTO_LITTLE_ENDIAN 1
+  #endif
+#else
+  /* Use the configure endian test */
+  #if !defined(XMOTO_LITTLE_ENDIAN) && !defined(XMOTO_BIG_ENDIAN)
+    /* Assume little endian */
+    #define XMOTO_LITTLE_ENDIAN 1
+  #endif
 #endif
 
 //used a comparator in sdt::map
