@@ -25,7 +25,11 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "Image.h"
 #include "VFileIO.h"
 #include "helpers/Log.h"
-#include "Renderer.h"
+#include "Game.h"
+#include "drawlib/DrawLib.h"
+#ifdef ENABLE_OPENGL
+#include "include/xm_OpenGL.h"
+#endif
 #include "Theme.h"
 #include "XMSession.h"
 
@@ -63,11 +67,19 @@ void Texture::removeAssociatedSprites()
   associatedSprites.clear();
 }
 
+  unsigned int TextureManager::m_curRegistrationStage=0;
+  bool TextureManager::m_registering = false;
+
+TextureManager::~TextureManager() {
+  for(unsigned int i=0; i<m_textureSizeCacheValues.size(); i++) {
+    free(m_textureSizeCacheValues[i]);
+  }
+}
 
   /*===========================================================================
   Create texture from memory
   ===========================================================================*/
-  Texture *TextureManager::createTexture(std::string Name,unsigned char *pcData,int nWidth,int nHeight,bool bAlpha,bool bClamp, FilterMode eFilterMode) {
+  Texture *TextureManager::createTexture(const std::string& Name,unsigned char *pcData,int nWidth,int nHeight,bool bAlpha,bool bClamp, FilterMode eFilterMode) {
     /* Name free? */
     if(getTexture(Name) != NULL) {
       LogWarning("TextureManager::createTexture() : Name '%s' already in use",Name.c_str());
@@ -225,7 +237,7 @@ void Texture::removeAssociatedSprites()
   /*===========================================================================
   Shortcut to loading textures from image files
   ===========================================================================*/  
-  Texture* TextureManager::loadTexture(std::string Path,bool bSmall,bool bClamp,
+  Texture* TextureManager::loadTexture(const std::string& Path,bool bSmall,bool bClamp,
 				       FilterMode eFilterMode, bool persistent,
 				       Sprite* associatedSprite) {
     /* Check file validity */
@@ -234,7 +246,7 @@ void Texture::removeAssociatedSprites()
     Texture *pTexture = NULL;
     
     /* Name it */
-    std::string TexName = FS::getFileBaseName(Path);
+    std::string TexName = XMFS::getFileBaseName(Path);
 
     /* if the texture is already loaded, return it */
     pTexture = getTexture(TexName);
@@ -244,6 +256,8 @@ void Texture::removeAssociatedSprites()
     }
 
     if(TextureImage.checkFile( Path,&ii )) {
+      LogDebug("Texture [%s] width = %i height = %i", Path.c_str(),
+	      ii.nWidth, ii.nHeight);
       /* Valid texture size? */
       if(ii.nWidth != ii.nHeight) {
         LogWarning("TextureManager::loadTexture() : texture '%s' is not square",Path.c_str());
@@ -287,10 +301,49 @@ void Texture::removeAssociatedSprites()
     return pTexture;
   }
   
+int TextureManager::getTextureSize(const std::string& p_fileName) {
+    image_info_t ii;
+    Img TextureImage;
+    int* v_val;
+
+    // cache
+    v_val = m_textureSizeCache[p_fileName.c_str()];
+    if(v_val != NULL) {
+      return *v_val;
+    }
+
+    if(TextureImage.checkFile(p_fileName, &ii)) {
+#if defined(__APPLE__) 
+      // on mac os x, ii.nWidth get a bad value.
+      // the loading seems to fix this value
+      
+      /* Load it into system memory */
+      TextureImage.loadFile(p_fileName, false);
+#endif
+      v_val = (int*) malloc(sizeof(int));
+      if(v_val == NULL) {
+	return 0;
+      } else {
+#if defined(__APPLE__)
+	*v_val = TextureImage.getWidth();
+#else
+	*v_val = ii.nWidth;
+#endif
+	m_textureSizeCacheKeys.push_back(p_fileName);
+	m_textureSizeCacheValues.push_back(v_val);
+	m_textureSizeCache[m_textureSizeCacheKeys[m_textureSizeCacheKeys.size()-1].c_str()] = v_val;
+
+      }
+
+      return *v_val;
+    } else
+      return 0;
+}
+
   /*===========================================================================
   Get loaded texture by name
   ===========================================================================*/  
-  Texture* TextureManager::getTexture(std::string Name) {
+  Texture* TextureManager::getTexture(const std::string& Name) {
     for(unsigned int i=0; i<m_Textures.size(); i++)
       if(m_Textures[i]->Name == Name)
 	return m_Textures[i];
@@ -314,6 +367,149 @@ void TextureManager::removeAssociatedSpritesFromTextures()
   Unload everything in a very hateful manner
   ===========================================================================*/
   void TextureManager::unloadTextures(void) {
-    while(!m_Textures.empty())
+
+    if(XMSession::instance()->debug() == true) {
+      LogDebug("---Texture not freed automatically---");
+
+      std::vector<Texture*> textures = getTextures();
+      std::vector<Texture*>::iterator it = textures.begin();
+
+      int i=1;
+      while(it != textures.end()){
+	if((*it)->curRegistrationStageMode != RSM_NORMAL || (*it)->curRegistrationStage.size() > 0) {
+	  LogDebug("%3i   %s (%s)", i, (*it)->Name.c_str(), (*it)->curRegistrationStageMode == RSM_NORMAL ? "NORMAL" : "PERSISTANT");
+	  i++;
+	}
+	++it;
+      }
+      LogDebug("--- --- ---");
+    }
+
+    while(!m_Textures.empty()) {
       destroyTexture(m_Textures[0]);
+    }
   }
+
+unsigned int TextureManager::beginTexturesRegistration()
+{
+  // not 2 registering in parallele
+  if(m_registering) {
+    throw Exception("Already registring in progress !!!");
+  }
+
+  m_registering = true;
+  m_curRegistrationStage++;
+
+  if(XMSession::instance()->debug() == true) {
+    LogDebug("---Begin texture registration---");
+    std::vector<Texture*> textures = getTextures();
+    std::vector<Texture*>::iterator it = textures.begin();
+    while(it != textures.end()){
+      if((*it)->curRegistrationStageMode != RSM_PERSISTANT) {
+	for(unsigned int i=0; i<(*it)->curRegistrationStage.size(); i++) {
+	  LogDebug("  begin %s %d [%x]", (*it)->Name.c_str(), (*it)->curRegistrationStage[i], (*it));
+	}
+      }
+      ++it;
+    }
+    LogDebug("---Begin texture registration---");
+  }
+
+  return m_curRegistrationStage;
+}
+
+void TextureManager::endTexturesRegistration()
+{
+  // remove not used textures
+  /*
+    removal of textures is done once a new registration is finished in case the new one uses textures of the old one (good probability, mainly if levels are the same)
+  */
+  cleanUnregistredTextures();
+
+  if(XMSession::instance()->debug() == true) {
+    std::vector<Texture*> textures = getTextures();
+    std::vector<Texture*>::iterator it = textures.begin();
+
+    LogDebug("---End texture registration---");
+    while(it != textures.end()){
+      if((*it)->curRegistrationStageMode != RSM_PERSISTANT) {
+	for(unsigned int i=0; i<(*it)->curRegistrationStage.size(); i++) {
+	  LogDebug("  end %s %d [%x]", (*it)->Name.c_str(), (*it)->curRegistrationStage[i], (*it));
+	}
+      }
+      ++it;
+    }
+    LogDebug("---End texture registration---");
+  }
+
+  m_registering = false;
+}
+
+void TextureManager::cleanUnregistredTextures() {
+  // as we will remove textures, the current texture in drawlib can
+  // became invalid -> set it to NULL
+  GameApp::instance()->getDrawLib()->setTexture(NULL, BLEND_MODE_NONE);
+
+  std::vector<Texture*> textures = getTextures();
+  std::vector<Texture*>::iterator it = textures.begin();
+
+  while(it != textures.end()){
+    // zero is for persistent textures
+    if((*it)->curRegistrationStageMode == RSM_NORMAL &&
+       (*it)->curRegistrationStage.size() == 0) {
+      LogDebug("remove texture [%s] [%x]", (*it)->Name.c_str(), (*it));
+      
+      (*it)->invalidateSpritesTexture();
+      
+      destroyTexture(*it);
+      it = textures.erase(it);
+    } else {
+      ++it;
+    }
+  }
+}
+
+bool TextureManager::registering(){
+  return m_registering;
+}
+
+unsigned int TextureManager::currentRegistrationStage(){
+  return m_curRegistrationStage;
+}
+
+void TextureManager::registerTexture(Texture* i_texture) {
+  i_texture->curRegistrationStageMode = RSM_NORMAL;
+  i_texture->curRegistrationStage.push_back(m_curRegistrationStage);
+}
+
+bool TextureManager::isRegisteredTexture(Texture* i_texture) {
+  if(i_texture->curRegistrationStageMode != RSM_NORMAL) {
+    return false;
+  }
+  for(unsigned int i=0; i<i_texture->curRegistrationStage.size(); i++) {
+    if(i_texture->curRegistrationStage[i] == m_curRegistrationStage) {
+      return true;
+    }
+  }
+  return false;
+}
+
+void TextureManager::unregister(unsigned int i_registerValue) {
+  std::vector<Texture*> textures = getTextures();
+  std::vector<Texture*>::iterator it = textures.begin();
+  unsigned int i;
+
+  while(it != textures.end()){
+    if((*it)->curRegistrationStageMode == RSM_NORMAL) {
+      i = 0;
+      while(i < (*it)->curRegistrationStage.size()) {
+	if((*it)->curRegistrationStage[i] == i_registerValue) {
+	  (*it)->curRegistrationStage.erase((*it)->curRegistrationStage.begin()+i);
+	} else {
+	  i++;
+	}
+      }
+    }
+    ++it;
+  }
+}
