@@ -45,6 +45,7 @@ class XMArguments {
   bool isOptWindowed() const;
   bool isOptFs() const;
   bool isOptNoExts() const;
+  bool isOptNoVOBS() const;
   bool isOptDrawlib() const;
   std::string getOpt_drawlib_lib() const;
   bool isOptHelp() const;
@@ -94,6 +95,10 @@ class XMArguments {
   bool isOptForceChildrenCompliant() const;
   bool isOptNoDBDirsCheck() const;
   bool isOptServerOnly() const;
+  bool isOptServerPort() const;
+  int getOptServerPort_value() const;
+  bool isOptServerAdminPassword() const;
+  std::string getOptServerAdminPassword_value() const;
   bool isOptUpdateLevelsOnly() const;
   bool isOptClientConnectAtStartup() const;
   bool isOptAdminMode() const;
@@ -118,6 +123,7 @@ class XMArguments {
   bool m_opt_fs;
   bool m_opt_win;
   bool m_opt_noexts;
+  bool m_opt_novobs;
   bool m_opt_drawlib;
   std::string m_drawlib_lib;
   bool m_opt_ugly;
@@ -188,6 +194,10 @@ class XMArguments {
 
   /* server */
   bool m_opt_serverOnly;
+  bool m_opt_serverPort;
+  int  m_opt_serverPort_value;
+  bool m_opt_serverAdminPassword;
+  std::string m_opt_serverAdminPassword_value;
 
   /* net */
   bool m_opt_clientConnectAtStartup;
