@@ -120,6 +120,7 @@ public:
   void setBpp(int i_value);
   void setWindowed(bool i_value);
   bool glExts() const;
+  bool glVOBS() const;
   std::string drawlib() const;
   bool www() const;
   void setWWW(bool i_value);
@@ -245,7 +246,6 @@ public:
   void setWebConfAtInit(bool i_value);
   bool webConfAtInit() const;
   bool storeReplays() const;
-  bool compressReplays() const;
   bool enableReplayInterpolation() const;
   void setEnableReplayInterpolation(bool i_value);
   std::string uploadHighscoreUrl() const;
@@ -329,6 +329,7 @@ public:
   int  m_maxRenderFps;
   bool m_windowed;
   bool m_glExts;
+  bool m_glVOBS;
   std::string m_drawlib;
   bool m_www;
   bool m_benchmark;
@@ -400,7 +401,6 @@ public:
   ProxySettings m_proxySettings;
   bool m_webConfAtInit;
   bool m_storeReplays;
-  bool m_compressReplays;
   bool m_enableReplayInterpolation;
   std::string m_screenshotFormat;
   std::string m_language;
