@@ -26,7 +26,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 class XmDatabaseUpdateInterface {
   public:
   virtual ~XmDatabaseUpdateInterface() {};
-  virtual void updatingDatabase(std::string i_message) = 0;
+  virtual void updatingDatabase(const std::string& i_message, int i_percentage) = 0;
 };
 
 #endif
