@@ -27,7 +27,8 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "../VFileIO.h"
 #include "../VFileIO_types.h"
 
-#define DRAW_FONT_FILE_GENERAL "Textures/Fonts/DejaVuSans.ttf"
+#define DRAW_FONT_FILE_GENERAL   "Textures/Fonts/DejaVuSans.ttf"
+#define DRAW_FONT_FILE_MONOSPACE "Textures/Fonts/DejaVuSansMono.ttf"
 
 #ifdef ASIAN_TTF_FILE
 #define DRAW_FONT_FILE_ASIAN ASIAN_TTF_FILE
@@ -43,6 +44,8 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "DrawLibSDLgfx.h"
 #endif
 
+bool DrawLib::m_initialized = false;
+
   DrawLib::backendtype DrawLib::m_backend = DrawLib::backend_None;
 
   DrawLib* DrawLib::DrawLibFromName(std::string i_drawLibName) {
@@ -73,10 +76,21 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
     return NULL;
   }
 
+void DrawLib::init(unsigned int nDispWidth, unsigned int nDispHeight, unsigned int nDispBPP, bool bWindowed) {
+  m_initialized = true;
+}
+
+bool DrawLib::isInitialized() {
+  return m_initialized;
+}
+
 void DrawLib::checkFontPrerequites() {
   if(XMFS::fileExists(FDT_DATA, FontManager::getDrawFontFile()) == false) {
     throw Exception("File " + FontManager::getDrawFontFile() + " is missing");
   }
+  if(XMFS::fileExists(FDT_DATA, FontManager::getMonospaceFontFile()) == false) {
+    throw Exception("File " + FontManager::getMonospaceFontFile() + " is missing");
+  }
 }
 
  DrawLib::DrawLib() {
@@ -86,6 +100,7 @@ void DrawLib::checkFontPrerequites() {
   m_bWindowed=true;
   m_bNoGraphics=false;
   m_bDontUseGLExtensions=false;
+  m_bDontUseGLVOBS=false;
   m_bShadersSupported = false;
   m_bVBOSupported = false;
   m_nLScissorX = m_nLScissorY = m_nLScissorW = m_nLScissorH = 0;
@@ -95,13 +110,15 @@ void DrawLib::checkFontPrerequites() {
 
   m_fontSmall  = NULL;
   m_fontMedium = NULL;
+  m_fontBig    = NULL;
+  m_fontMonospace = NULL;
  };
 
  DrawLib::~DrawLib() {
  }
 
 
-  FontManager* DrawLib::getFontManager(const std::string &i_fontFile, unsigned int i_fontSize) {
+  FontManager* DrawLib::getFontManager(const std::string &i_fontFile, unsigned int i_fontSize, unsigned int i_fixedFontSize) {
     throw Exception("Your DrawLib doesn't manage FontManager");
   }
 
@@ -126,6 +143,13 @@ void DrawLib::checkFontPrerequites() {
     return m_fontBig;
   }
 
+  FontManager* DrawLib::getFontMonospace() {
+    if(m_fontMonospace == NULL) {
+      throw Exception("Invalid font");
+    }
+    return m_fontMonospace;
+  }
+
    /*===========================================================================
   Primitive: box
   ===========================================================================*/
@@ -370,6 +394,10 @@ void DrawLib::setDontUseGLExtensions(bool dont_use) {
   m_bDontUseGLExtensions = dont_use;
 }
 
+void DrawLib::setDontUseGLVOBS(bool dont_use) {
+  m_bDontUseGLVOBS = dont_use;
+}
+
 bool DrawLib::useVBOs() {
   return m_bVBOSupported;
 };
@@ -449,13 +477,14 @@ void DrawLib::drawImageTextureSet(const Vector2f &a,const Vector2f &b, const Vec
     }
   }
 
-FontManager::FontManager(DrawLib* i_drawLib, const std::string &i_fontFile, unsigned int i_fontSize) {
+FontManager::FontManager(DrawLib* i_drawLib, const std::string &i_fontFile, unsigned int i_fontSize, unsigned int i_fixedFontSize) {
   m_drawLib = i_drawLib;
   m_ttf = TTF_OpenFont(i_fontFile.c_str(), i_fontSize);
   if (m_ttf == NULL) {
     throw Exception("FontManager: " + std::string(TTF_GetError()));
   }
   TTF_SetFontStyle(m_ttf, TTF_STYLE_NORMAL);
+  m_fixedFontSize = i_fixedFontSize;
 }
 
 FontManager::~FontManager() {
@@ -468,3 +497,7 @@ std::string FontManager::getDrawFontFile() {
 
   return DRAW_FONT_FILE_GENERAL;
 }
+
+std::string FontManager::getMonospaceFontFile() {
+  return DRAW_FONT_FILE_MONOSPACE;
+}
