@@ -43,10 +43,11 @@ class FontGlyph {
 
 class FontManager {
  public:
-  FontManager(DrawLib* i_drawLib, const std::string &i_fontFile, unsigned int i_fontSize);
+  FontManager(DrawLib* i_drawLib, const std::string &i_fontFile, unsigned int i_fontSize, unsigned int i_fixedFontSize = 0 /* if > 0, force width */);
   virtual ~FontManager();
   
   virtual FontGlyph* getGlyph(const std::string& i_string) = 0;
+  virtual FontGlyph* getGlyphTabExtended(const std::string& i_string) = 0; // extends \t
   
   virtual void printString(DrawLib* pDrawLib, FontGlyph* i_glyph, int i_x, int i_y, Color i_color, float i_perCentered = -1.0, bool i_shadowEffect = false) = 0;
   virtual void printStringGrad(DrawLib* pDrawLib, FontGlyph* i_glyph, int i_x, int i_y,
@@ -54,10 +55,14 @@ class FontManager {
   
 
   static std::string getDrawFontFile();
+  static std::string getMonospaceFontFile();
+
+  virtual void displayScrap(DrawLib* pDrawLib) = 0;
 
  protected:
   TTF_Font* m_ttf;
   DrawLib* m_drawLib;
+  unsigned int m_fixedFontSize;
 };
 
 
@@ -107,8 +112,9 @@ class DrawLib {
   /**
    * initialize the screen
    **/
+  static bool isInitialized();
   virtual void init(unsigned int nDispWidth, unsigned int nDispHeight,
-		    unsigned int nDispBPP, bool bWindowed) = 0;
+		    unsigned int nDispBPP, bool bWindowed);
   
   virtual void unInit() = 0;
   
@@ -212,6 +218,7 @@ class DrawLib {
 
   virtual bool isExtensionSupported(std::string Ext) = 0;
   void setDontUseGLExtensions(bool dont_use);
+  void setDontUseGLVOBS(bool dont_use);
   virtual Img *grabScreen(int i_reduce = 1) = 0;
 
   /*
@@ -228,7 +235,8 @@ class DrawLib {
   FontManager* getFontSmall();
   FontManager* getFontMedium();
   FontManager* getFontBig();
-  virtual FontManager* getFontManager(const std::string &i_fontFile, unsigned int i_fontSize);
+  FontManager* getFontMonospace();
+  virtual FontManager* getFontManager(const std::string &i_fontFile, unsigned int i_fontSize, unsigned int i_fixedFontSize = 0 /* if > 0, force width */);
   static void checkFontPrerequites();
 
   Camera* getMenuCamera();
@@ -240,6 +248,7 @@ class DrawLib {
   FontManager* m_fontSmall;
   FontManager* m_fontMedium;
   FontManager* m_fontBig;
+  FontManager* m_fontMonospace;
 
   bool m_bWindowed;		/* Windowed or not */
 
@@ -250,6 +259,7 @@ class DrawLib {
   bool m_bFBOSupported;
   bool m_bShadersSupported;
   bool m_bDontUseGLExtensions;
+  bool m_bDontUseGLVOBS;
   bool m_bNoGraphics;		/* No-graphics mode */
   
   SDL_Surface *m_screen;
@@ -258,6 +268,7 @@ class DrawLib {
 
  private:
   static backendtype m_backend;
+  static bool m_initialized;
 };
 
 #endif
