@@ -52,13 +52,16 @@ public:
   bool isDirty();
   void update();
 
-  void drawDebug();
+  void display(DrawLib* pDrawLib);
 
 private:
   #define MAX_SCRAPS   4
+  // we need 3dfx first gen compatibility, which has only 256x256 max
+  // texture size
   #define BLOCK_WIDTH  256
   #define BLOCK_HEIGHT 256
 
+  // store the first available y
   unsigned int m_scrapsAllocated[MAX_SCRAPS][BLOCK_WIDTH];
   SDL_Surface* m_scrapsTexels[MAX_SCRAPS];
   bool         m_scrapsUsed[MAX_SCRAPS];
@@ -98,7 +101,7 @@ protected:
 
 class GLFontGlyphLetter : public GLFontGlyph {
 public:
-  GLFontGlyphLetter(const std::string& i_value, TTF_Font* i_ttf);
+  GLFontGlyphLetter(const std::string& i_value, TTF_Font* i_ttf, unsigned int i_fixedFontSize);
   virtual ~GLFontGlyphLetter();
   GLuint GLID() const;  
 
@@ -112,10 +115,11 @@ private:
 
 class GLFontManager : public FontManager {
 public:
-  GLFontManager(DrawLib* i_drawLib, const std::string &i_fontFile, unsigned int i_fontSize);
+  GLFontManager(DrawLib* i_drawLib, const std::string &i_fontFile, unsigned int i_fontSize, unsigned int i_fixedFontSize = 0);
   virtual ~GLFontManager();
 
   FontGlyph* getGlyph(const std::string& i_string);
+  FontGlyph* getGlyphTabExtended(const std::string& i_string);
   void printString(DrawLib* pDrawLib, FontGlyph* i_glyph, int i_x, int i_y, Color i_color, float i_perCentered = -1.0, bool i_shadowEffect = false);
   void printStringGrad(DrawLib* pDrawLib, FontGlyph* i_glyph, int i_x, int i_y,
 		       Color c1, Color c2, Color c3, Color c4, float i_perCentered = -1.0, bool i_shadowEffect = false);
@@ -123,12 +127,15 @@ public:
 			  Color c1, Color c2, Color c3, Color c4, float i_perCentered = -1.0);
 
   virtual unsigned int nbGlyphsInMemory();
+  virtual void displayScrap(DrawLib* pDrawLib);
 
 private:
-  std::vector<GLFontGlyph*> m_glyphsList;
+  std::vector<std::string> m_glyphsKeys;
+  std::vector<GLFontGlyph*> m_glyphsValues;
   HashNamespace::hash_map<const char*, GLFontGlyph*, HashNamespace::hash<const char*>, hashcmp_str> m_glyphs;
 
-  std::vector<GLFontGlyphLetter*> m_glyphsLettersList;
+  std::vector<std::string> m_glyphsLettersKeys;
+  std::vector<GLFontGlyphLetter*> m_glyphsLettersValues;
   HashNamespace::hash_map<const char*, GLFontGlyphLetter*, HashNamespace::hash<const char*>, hashcmp_str> m_glyphsLetters;
 
   unsigned int getLonguestLineSize(const std::string& i_value, unsigned int i_start = 0, unsigned int i_nbLinesToRead = -1);
@@ -149,12 +156,17 @@ DrawLibOpenGL::~DrawLibOpenGL(){
   if(m_fontBig != NULL) {
     delete m_fontBig;
   }
+
+  if(m_fontMonospace != NULL) {
+    delete m_fontMonospace;
+  }
 }
 
 DrawLibOpenGL::DrawLibOpenGL() : DrawLib(){
-  m_fontSmall  = getFontManager(XMFS::FullPath(FDT_DATA, FontManager::getDrawFontFile()), 14);
-  m_fontMedium = getFontManager(XMFS::FullPath(FDT_DATA, FontManager::getDrawFontFile()), 22);
-  m_fontBig    = getFontManager(XMFS::FullPath(FDT_DATA, FontManager::getDrawFontFile()), 60);
+  m_fontSmall     = getFontManager(XMFS::FullPath(FDT_DATA, FontManager::getDrawFontFile()), 14);
+  m_fontMedium    = getFontManager(XMFS::FullPath(FDT_DATA, FontManager::getDrawFontFile()), 22);
+  m_fontBig       = getFontManager(XMFS::FullPath(FDT_DATA, FontManager::getDrawFontFile()), 60);
+  m_fontMonospace = getFontManager(XMFS::FullPath(FDT_DATA, FontManager::getMonospaceFontFile()), 12, 7);
 };
  
 /*===========================================================================
@@ -216,7 +228,9 @@ void DrawLibOpenGL::setLineWidth(float width){
   glLineWidth(width);
 }
  
-void DrawLibOpenGL::init(unsigned int nDispWidth, unsigned int nDispHeight, unsigned int nDispBPP, bool bWindowed){
+void DrawLibOpenGL::init(unsigned int nDispWidth, unsigned int nDispHeight, unsigned int nDispBPP, bool bWindowed) {
+  DrawLib::init(nDispWidth, nDispHeight, nDispBPP, bWindowed);
+
   /* Set suggestions */
   m_nDispWidth  = nDispWidth;
   m_nDispHeight = nDispHeight;
@@ -299,9 +313,14 @@ void DrawLibOpenGL::init(unsigned int nDispWidth, unsigned int nDispHeight, unsi
     m_bVBOSupported     = false;
     m_bFBOSupported     = false;
     m_bShadersSupported = false;
-  }
-  else {
-    m_bVBOSupported = isExtensionSupported("GL_ARB_vertex_buffer_object");
+  } else {
+
+    if(m_bDontUseGLVOBS) {
+      m_bVBOSupported = false;
+    } else {
+      m_bVBOSupported = isExtensionSupported("GL_ARB_vertex_buffer_object");
+    }
+
     m_bFBOSupported = isExtensionSupported("GL_EXT_framebuffer_object");
       
     m_bShadersSupported = isExtensionSupported("GL_ARB_fragment_shader")
@@ -579,6 +598,7 @@ SDL_Surface* createSDLSurface(unsigned int width,
 
 ScrapTextures::ScrapTextures()
 {
+  m_dirty = false;
   memset(m_scrapsAllocated, 0, sizeof(unsigned int) * BLOCK_WIDTH * MAX_SCRAPS);
   for(unsigned int i=0; i<MAX_SCRAPS; i++){
     m_scrapsTexels[i] = createSDLSurface(BLOCK_WIDTH, BLOCK_HEIGHT);
@@ -610,7 +630,7 @@ int ScrapTextures::allocateAndLoadTexture(unsigned int width,
 
       unsigned int j;
       for(j=0; j<width; j++){
-	if(m_scrapsAllocated[scrap][i+j] >= BLOCK_HEIGHT){
+	if(m_scrapsAllocated[scrap][i+j] + height >= BLOCK_HEIGHT){
 	  break;
 	}
 	if(m_scrapsAllocated[scrap][i+j] > firstAvailable)
@@ -625,11 +645,8 @@ int ScrapTextures::allocateAndLoadTexture(unsigned int width,
       }
     }
 
-    if(useScrap == true
-       && firstAvailable + height <= BLOCK_HEIGHT)
-      break;
-
-    scrap++;
+    if(useScrap == false)
+      scrap++;
   }
 
   if(useScrap == true){
@@ -688,11 +705,29 @@ void ScrapTextures::update()
   }
 }
 
-FontManager* DrawLibOpenGL::getFontManager(const std::string &i_fontFile, unsigned int i_fontSize) {
-  return new GLFontManager(this, i_fontFile, i_fontSize);
+void ScrapTextures::display(DrawLib* pDrawLib)
+{
+    for(unsigned int i=0; i<MAX_SCRAPS; i++){
+      if(m_scrapsUsed[i] == false)
+	continue;
+
+      glEnable(GL_TEXTURE_2D);
+      glEnable(GL_BLEND);
+      glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+      glBindTexture(GL_TEXTURE_2D, m_scrapsTextures[i]);
+      pDrawLib->drawImageTextureSet(Vector2f(0.0 + i*BLOCK_WIDTH, 200.0),
+				    Vector2f(BLOCK_WIDTH + i*BLOCK_WIDTH, 200.0),
+				    Vector2f(BLOCK_WIDTH + i*BLOCK_WIDTH, 200+BLOCK_HEIGHT),
+				    Vector2f(0.0 + i*BLOCK_WIDTH, 200+BLOCK_HEIGHT),
+				    MAKE_COLOR(255,255,255,255), true);
+    }
 }
 
-GLFontGlyphLetter::GLFontGlyphLetter(const std::string& i_value, TTF_Font* i_ttf)
+FontManager* DrawLibOpenGL::getFontManager(const std::string &i_fontFile, unsigned int i_fontSize, unsigned int i_fixedFontSize) {
+  return new GLFontManager(this, i_fontFile, i_fontSize, i_fixedFontSize);
+}
+
+GLFontGlyphLetter::GLFontGlyphLetter(const std::string& i_value, TTF_Font* i_ttf, unsigned int i_fixedFontSize)
   : GLFontGlyph(i_value) {
   SDL_Surface* v_surf;
   SDL_Surface* v_image;
@@ -715,11 +750,19 @@ GLFontGlyphLetter::GLFontGlyphLetter(const std::string& i_value, TTF_Font* i_ttf
   m_realWidth = (unsigned int) v_realWidth;
   m_realHeight = (unsigned int) v_realHeight;
 
-  m_drawWidth  = powerOf2(m_realWidth);
-  m_drawHeight = powerOf2(m_realHeight);
+  m_drawWidth  = m_realWidth;
+  m_drawHeight = m_realHeight;
   m_firstLineDrawHeight = m_drawHeight;
 
-  if(m_drawWidth < 64 && m_drawHeight < 64) {
+  // hack because ttf even width fixed fonts return not perfectly fixed fonts
+  if(i_fixedFontSize != 0) {
+    if(TTF_FontFaceIsFixedWidth(i_ttf)) {
+      m_drawWidth = m_realWidth = i_fixedFontSize;
+    }
+  }
+
+  // maximum width/heigth allowed, 80, when bigger, create a texture
+  if(m_drawWidth < 80 && m_drawHeight < 80) {
     try{
       m_GLID = ScrapTextures::instance()->allocateAndLoadTexture(m_drawWidth, m_drawHeight,
 								 &m_u.x, &m_u.y,
@@ -736,6 +779,8 @@ GLFontGlyphLetter::GLFontGlyphLetter(const std::string& i_value, TTF_Font* i_ttf
   dont_use_crap:
     m_useScrap = false;
 
+    m_drawWidth  = powerOf2(m_realWidth);
+    m_drawHeight = powerOf2(m_realHeight);
     v_image = createSDLSurface(m_drawWidth, m_drawHeight);
 
     /* Copy the surface into the GL texture image */
@@ -824,9 +869,9 @@ GLFontGlyph::GLFontGlyph(const std::string& i_value,
     m_firstLineDrawHeight = v_maxHeight;
   }
 
-  m_drawWidth  = powerOf2(m_realWidth);
-  m_drawHeight = powerOf2(m_realHeight);
-  m_firstLineDrawHeight = powerOf2(m_firstLineDrawHeight);
+  m_drawWidth  = m_realWidth;
+  m_drawHeight = m_realHeight;
+  m_firstLineDrawHeight = m_firstLineDrawHeight;
 }
 
 GLFontGlyph::~GLFontGlyph() {
@@ -858,21 +903,25 @@ unsigned int GLFontGlyph::firstLineDrawHeight() const {
 
 
 
-GLFontManager::GLFontManager(DrawLib* i_drawLib, const std::string &i_fontFile, unsigned int i_fontSize)
-  : FontManager(i_drawLib, i_fontFile, i_fontSize) {
+GLFontManager::GLFontManager(DrawLib* i_drawLib, const std::string &i_fontFile, unsigned int i_fontSize, unsigned int i_fixedFontSize)
+: FontManager(i_drawLib, i_fontFile, i_fontSize, i_fixedFontSize) {
 }
 
 unsigned int GLFontManager::nbGlyphsInMemory() {
-  return m_glyphsLettersList.size();
+  return m_glyphsLettersValues.size();
+}
+
+void GLFontManager::displayScrap(DrawLib* pDrawLib) {
+  ScrapTextures::instance()->display(pDrawLib);
 }
 
 GLFontManager::~GLFontManager() {
-  for(unsigned int i=0; i<m_glyphsList.size(); i++) {
-    delete m_glyphsList[i];
+  for(unsigned int i=0; i<m_glyphsValues.size(); i++) {
+    delete m_glyphsValues[i];
   }
 
-  for(unsigned int i=0; i<m_glyphsLettersList.size(); i++) {
-    delete m_glyphsLettersList[i];
+  for(unsigned int i=0; i<m_glyphsLettersValues.size(); i++) {
+    delete m_glyphsLettersValues[i];
   }
 
   /* i added the m_glyphsList because the iterator on the hashmap
@@ -894,6 +943,26 @@ int GLFontGlyph::powerOf2(int i_value) {
   return v_value;
 }
 
+FontGlyph* GLFontManager::getGlyphTabExtended(const std::string& i_string) {
+  std::string v_extstr;
+  unsigned int v_tab_size = 5;
+
+  unsigned int n = 0;
+  std::string v_char;
+  while(n < i_string.size()) {
+    v_char = utf8::getNextChar(i_string, n);
+    if(v_char == "\t") {
+      for(unsigned int i=n%v_tab_size; i<v_tab_size; i++) {
+	v_extstr += " ";
+      }
+    } else {
+      v_extstr += v_char;
+    }
+  }
+
+  return getGlyph(v_extstr);
+}
+
 FontGlyph* GLFontManager::getGlyph(const std::string& i_string) {
   GLFontGlyph *v_glyph;
   GLFontGlyphLetter *v_glyphLetter;
@@ -908,18 +977,19 @@ FontGlyph* GLFontManager::getGlyph(const std::string& i_string) {
     v_char = utf8::getNextChar(i_string, n);
     if(v_char != "\n") {
       if(m_glyphsLetters[v_char.c_str()] == NULL) {
-	v_glyphLetter = new GLFontGlyphLetter(v_char, m_ttf);
-	m_glyphsLetters[v_char.c_str()] = v_glyphLetter;
-	m_glyphsLettersList.push_back(v_glyphLetter);
+	v_glyphLetter = new GLFontGlyphLetter(v_char, m_ttf, m_fixedFontSize);
+	m_glyphsLettersKeys.push_back(v_char);
+	m_glyphsLettersValues.push_back(v_glyphLetter);
+	m_glyphsLetters[m_glyphsLettersKeys[m_glyphsLettersKeys.size()-1].c_str()] = v_glyphLetter;
       }
     }
   }
   /* */
 
   v_glyph = new GLFontGlyph(i_string, m_glyphsLetters);
-  
-  m_glyphs[i_string.c_str()] = v_glyph;
-  m_glyphsList.push_back(v_glyph);
+  m_glyphsKeys.push_back(i_string);
+  m_glyphsValues.push_back(v_glyph);  
+  m_glyphs[m_glyphsKeys[m_glyphsKeys.size()-1].c_str()] = v_glyph;
 
   return v_glyph;
 }
