@@ -25,6 +25,10 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 template<typename T> class Singleton {
 public:
+  static bool exists() {
+    return m_pInstance != NULL;
+  }
+
   static T* instance() {
     if(m_pInstance == NULL){
       m_pInstance = new T();
