@@ -25,7 +25,8 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include <stdio.h>
 #include <string.h>
 #include "tim.h"
-#include "png.h"
+#include <png.h>
+#include <zlib.h>
 
 /*==============================================================================
 Types
