@@ -30,6 +30,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include <sstream>
 #include "../helpers/SwapEndian.h"
 #include "helpers/Net.h"
+#include "helpers/utf8.h"
 
 char NetAction::m_buffer[NETACTION_MAX_PACKET_SIZE];
 unsigned int NetAction::m_biggestTCPPacketSent = 0;
@@ -51,6 +52,7 @@ std::string NA_changeName::ActionKey    = "changeName";
 std::string NA_playingLevel::ActionKey  = "playingLevel";
 std::string NA_serverError::ActionKey   = "serverError";
 std::string NA_changeClients::ActionKey = "changeClients";
+std::string NA_slaveClientsPoints::ActionKey = "scpoints";
 std::string NA_clientsNumber::ActionKey = "clientsNumber";
 std::string NA_clientsNumberQuery::ActionKey = "clientsNumberQ";
 // control : while it's sent a lot, reduce it at maximum
@@ -63,6 +65,7 @@ std::string NA_prepareToGo::ActionKey   = "prepareToGo";
 std::string NA_gameEvents::ActionKey    = "e";
 std::string NA_srvCmd::ActionKey        = "srvCmd";
 std::string NA_srvCmdAsw::ActionKey     = "srvCmdAsw";
+std::string NA_ping::ActionKey          = "ping";
 
 NetActionType NA_chatMessage::NAType   = TNA_chatMessage;
 NetActionType NA_chatMessagePP::NAType = TNA_chatMessagePP;
@@ -77,6 +80,7 @@ NetActionType NA_clientsNumberQuery::NAType = TNA_clientsNumberQuery;
 NetActionType NA_playingLevel::NAType  = TNA_playingLevel;
 NetActionType NA_serverError::NAType   = TNA_serverError;
 NetActionType NA_changeClients::NAType = TNA_changeClients;
+NetActionType NA_slaveClientsPoints::NAType = TNA_slaveClientsPoints;
 NetActionType NA_playerControl::NAType = TNA_playerControl;
 NetActionType NA_clientMode::NAType    = TNA_clientMode;
 NetActionType NA_prepareToPlay::NAType = TNA_prepareToPlay;
@@ -85,6 +89,7 @@ NetActionType NA_prepareToGo::NAType   = TNA_prepareToGo;
 NetActionType NA_gameEvents::NAType    = TNA_gameEvents;
 NetActionType NA_srvCmd::NAType        = TNA_srvCmd;
 NetActionType NA_srvCmdAsw::NAType     = TNA_srvCmdAsw;
+NetActionType NA_ping::NAType          = TNA_ping;
 
 NetAction::NetAction(bool i_forceTcp) {
   m_source    = -2; // < -1 => undefined
@@ -95,33 +100,14 @@ NetAction::NetAction(bool i_forceTcp) {
 NetAction::~NetAction() {
 }
 
-/* std::string version */
-std::string NetAction::getStats() {
-  std::string v_stats;
-
-  std::ostringstream v_nbTCPSent, v_nbUDPSent;
-
-  v_nbTCPSent << NetAction::m_nbTCPPacketsSent;
-  v_nbUDPSent << NetAction::m_nbUDPPacketsSent;
-
-  v_stats += "number of TCP packets sent : " + v_nbTCPSent.str()                                       + "\n";
-  v_stats += "biggest TCP packet sent : "    + XMNet::getFancyBytes(NetAction::m_biggestTCPPacketSent) + "\n";
-  v_stats += "size of TCP packets sent : "   + XMNet::getFancyBytes(NetAction::m_TCPPacketsSizeSent)   + "\n";
-  v_stats += "number of UDP packets sent : " + v_nbUDPSent.str()                                       + "\n";
-  v_stats += "biggest UDP packet sent : "    + XMNet::getFancyBytes(NetAction::m_biggestUDPPacketSent) + "\n";
-  v_stats += "size of UDP packets sent : "   + XMNet::getFancyBytes(NetAction::m_UDPPacketsSizeSent);
-
-  return v_stats;
-}
-
 /* log version */
 void NetAction::logStats() {
-  LogInfo("%-31s : %u", "net: number of TCP packets sent", NetAction::m_nbTCPPacketsSent);
-  LogInfo("%-31s : %s", "net: biggest TCP packet sent"   , XMNet::getFancyBytes(NetAction::m_biggestTCPPacketSent).c_str());
-  LogInfo("%-31s : %s", "net: size of TCP packets sent"  , XMNet::getFancyBytes(NetAction::m_TCPPacketsSizeSent).c_str());
-  LogInfo("%-31s : %u", "net: number of UDP packets sent", NetAction::m_nbUDPPacketsSent);
-  LogInfo("%-31s : %s", "net: biggest UDP packet sent"   , XMNet::getFancyBytes(NetAction::m_biggestUDPPacketSent).c_str());
-  LogInfo("%-31s : %s", "net: size of UDP packets sent"  , XMNet::getFancyBytes(NetAction::m_UDPPacketsSizeSent).c_str());
+  LogInfo("%-36s : %u", "net: number of TCP packets sent", NetAction::m_nbTCPPacketsSent);
+  LogInfo("%-36s : %s", "net: biggest TCP packet sent"   , XMNet::getFancyBytes(NetAction::m_biggestTCPPacketSent).c_str());
+  LogInfo("%-36s : %s", "net: size of TCP packets sent"  , XMNet::getFancyBytes(NetAction::m_TCPPacketsSizeSent).c_str());
+  LogInfo("%-36s : %u", "net: number of UDP packets sent", NetAction::m_nbUDPPacketsSent);
+  LogInfo("%-36s : %s", "net: biggest UDP packet sent"   , XMNet::getFancyBytes(NetAction::m_biggestUDPPacketSent).c_str());
+  LogInfo("%-36s : %s", "net: size of UDP packets sent"  , XMNet::getFancyBytes(NetAction::m_UDPPacketsSizeSent).c_str());
 }
 
 void NetAction::send(TCPsocket* i_tcpsd, UDPsocket* i_udpsd, UDPpacket* i_sendPacket, IPaddress* i_udpRemoteIP,
@@ -206,11 +192,10 @@ int NetAction::getSubSource() const {
   return m_subsource;
 }
 
-NetAction* NetAction::newNetAction(void* data, unsigned int len) {
+void NetAction::getNetAction(NetActionU* o_netAction, void* data, unsigned int len) {
   std::string v_cmd;
   int v_src, v_subsrc;
   unsigned int v_totalOffset = 0;
-  NetAction* v_res;
 
   v_src = atoi(getLine(((char*)data)+v_totalOffset, len-v_totalOffset, &v_totalOffset).c_str());
   v_subsrc = atoi(getLine(((char*)data+v_totalOffset), len-v_totalOffset, &v_totalOffset).c_str());
@@ -223,88 +208,119 @@ NetAction* NetAction::newNetAction(void* data, unsigned int len) {
 
   //printf("cmd = %s (%i/%i)\n", v_cmd.c_str(), v_totalOffset, len-v_totalOffset);
 
-  if(v_cmd == NA_chatMessage::ActionKey) {
-    v_res = new NA_chatMessage(((char*)data)+v_totalOffset, len-v_totalOffset);
-  }
-
-  else if(v_cmd == NA_chatMessagePP::ActionKey) {
-    v_res = new NA_chatMessagePP(((char*)data)+v_totalOffset, len-v_totalOffset);
-  }
-
-  else if(v_cmd == NA_frame::ActionKey) {
-    v_res = new NA_frame(((char*)data)+v_totalOffset, len-v_totalOffset);
+  if(v_cmd == NA_frame::ActionKey) {
+    o_netAction->frame = NA_frame(((char*)data)+v_totalOffset, len-v_totalOffset);
+    o_netAction->master = &(o_netAction->frame);
   }
 
   else if(v_cmd == NA_playerControl::ActionKey) {
-    v_res = new NA_playerControl(((char*)data)+v_totalOffset, len-v_totalOffset);
+    o_netAction->playerControl = NA_playerControl(((char*)data)+v_totalOffset, len-v_totalOffset);
+    o_netAction->master = &(o_netAction->playerControl);
+  }
+
+  else if(v_cmd == NA_chatMessage::ActionKey) {
+    o_netAction->chatMessage = NA_chatMessage(((char*)data)+v_totalOffset, len-v_totalOffset);
+    o_netAction->master = &(o_netAction->chatMessage);
+  }
+
+  else if(v_cmd == NA_chatMessagePP::ActionKey) {
+    o_netAction->chatMessagePP = NA_chatMessagePP(((char*)data)+v_totalOffset, len-v_totalOffset);
+    o_netAction->master = &(o_netAction->chatMessagePP);
   }
 
   else if(v_cmd == NA_clientInfos::ActionKey) {
-    v_res = new NA_clientInfos(((char*)data)+v_totalOffset, len-v_totalOffset);
+    o_netAction->clientInfos = NA_clientInfos(((char*)data)+v_totalOffset, len-v_totalOffset);
+    o_netAction->master = &(o_netAction->clientInfos);
   }
 
   else if(v_cmd == NA_udpBindQuery::ActionKey) {
-    v_res = new NA_udpBindQuery(((char*)data)+v_totalOffset, len-v_totalOffset);
+    o_netAction->udpBindQuery = NA_udpBindQuery(((char*)data)+v_totalOffset, len-v_totalOffset);
+    o_netAction->master = &(o_netAction->udpBindQuery);
   }
 
   else if(v_cmd == NA_udpBindValidation::ActionKey) {
-    v_res = new NA_udpBindValidation(((char*)data)+v_totalOffset, len-v_totalOffset);
+    o_netAction->udpBindValidation = NA_udpBindValidation(((char*)data)+v_totalOffset, len-v_totalOffset);
+    o_netAction->master = &(o_netAction->udpBindValidation);
   }
 
   else if(v_cmd == NA_udpBind::ActionKey) {
-    v_res = new NA_udpBind(((char*)data)+v_totalOffset, len-v_totalOffset);
+    o_netAction->udpBind = NA_udpBind(((char*)data)+v_totalOffset, len-v_totalOffset);
+    o_netAction->master = &(o_netAction->udpBind);
   }
 
   else if(v_cmd == NA_changeName::ActionKey) {
-    v_res = new NA_changeName(((char*)data)+v_totalOffset, len-v_totalOffset);
+    o_netAction->changeName = NA_changeName(((char*)data)+v_totalOffset, len-v_totalOffset);
+    o_netAction->master = &(o_netAction->changeName);
   }
 
   else if(v_cmd == NA_playingLevel::ActionKey) {
-    v_res = new NA_playingLevel(((char*)data)+v_totalOffset, len-v_totalOffset);
+    o_netAction->playingLevel = NA_playingLevel(((char*)data)+v_totalOffset, len-v_totalOffset);
+    o_netAction->master = &(o_netAction->playingLevel);
   }
 
   else if(v_cmd == NA_serverError::ActionKey) {
-    v_res = new NA_serverError(((char*)data)+v_totalOffset, len-v_totalOffset);
+    o_netAction->serverError = NA_serverError(((char*)data)+v_totalOffset, len-v_totalOffset);
+    o_netAction->master = &(o_netAction->serverError);
   }
 
   else if(v_cmd == NA_changeClients::ActionKey) {
-    v_res = new NA_changeClients(((char*)data)+v_totalOffset, len-v_totalOffset);
+    o_netAction->changeClients = NA_changeClients(((char*)data)+v_totalOffset, len-v_totalOffset);
+    o_netAction->master = &(o_netAction->changeClients);
+  }
+
+  else if(v_cmd == NA_slaveClientsPoints::ActionKey) {
+    o_netAction->slaveClientsPoints = NA_slaveClientsPoints(((char*)data)+v_totalOffset, len-v_totalOffset);
+    o_netAction->master = &(o_netAction->slaveClientsPoints);
   }
 
   else if(v_cmd == NA_clientsNumber::ActionKey) {
-    v_res = new NA_clientsNumber(((char*)data)+v_totalOffset, len-v_totalOffset);
+    o_netAction->clientsNumber = NA_clientsNumber(((char*)data)+v_totalOffset, len-v_totalOffset);
+    o_netAction->master = &(o_netAction->clientsNumber);
   }
 
   else if(v_cmd == NA_clientsNumberQuery::ActionKey) {
-    v_res = new NA_clientsNumberQuery(((char*)data)+v_totalOffset, len-v_totalOffset);
+    o_netAction->clientsNumberQuery = NA_clientsNumberQuery(((char*)data)+v_totalOffset, len-v_totalOffset);
+    o_netAction->master = &(o_netAction->clientsNumberQuery);
   }
 
   else if(v_cmd == NA_clientMode::ActionKey) {
-    v_res = new NA_clientMode(((char*)data)+v_totalOffset, len-v_totalOffset);
+    o_netAction->clientMode = NA_clientMode(((char*)data)+v_totalOffset, len-v_totalOffset);
+    o_netAction->master = &(o_netAction->clientMode);
   }
 
   else if(v_cmd == NA_prepareToPlay::ActionKey) {
-    v_res = new NA_prepareToPlay(((char*)data)+v_totalOffset, len-v_totalOffset);
+    o_netAction->prepareToPlay = NA_prepareToPlay(((char*)data)+v_totalOffset, len-v_totalOffset);
+    o_netAction->master = &(o_netAction->prepareToPlay);
   }
 
   else if(v_cmd == NA_killAlert::ActionKey) {
-    v_res = new NA_killAlert(((char*)data)+v_totalOffset, len-v_totalOffset);
+    o_netAction->killAlert = NA_killAlert(((char*)data)+v_totalOffset, len-v_totalOffset);
+    o_netAction->master = &(o_netAction->killAlert);
   }
 
   else if(v_cmd == NA_prepareToGo::ActionKey) {
-    v_res = new NA_prepareToGo(((char*)data)+v_totalOffset, len-v_totalOffset);
+    o_netAction->prepareToGo = NA_prepareToGo(((char*)data)+v_totalOffset, len-v_totalOffset);
+    o_netAction->master = &(o_netAction->prepareToGo);
   }
 
   else if(v_cmd == NA_gameEvents::ActionKey) {
-    v_res = new NA_gameEvents(((char*)data)+v_totalOffset, len-v_totalOffset);
+    o_netAction->gameEvents = NA_gameEvents(((char*)data)+v_totalOffset, len-v_totalOffset);
+    o_netAction->master = &(o_netAction->gameEvents);
   }
 
   else if(v_cmd == NA_srvCmd::ActionKey) {
-    v_res = new NA_srvCmd(((char*)data)+v_totalOffset, len-v_totalOffset);
+    o_netAction->srvCmd = NA_srvCmd(((char*)data)+v_totalOffset, len-v_totalOffset);
+    o_netAction->master = &(o_netAction->srvCmd);
   }
 
   else if(v_cmd == NA_srvCmdAsw::ActionKey) {
-    v_res = new NA_srvCmdAsw(((char*)data)+v_totalOffset, len-v_totalOffset);
+    o_netAction->srvCmdAsw = NA_srvCmdAsw(((char*)data)+v_totalOffset, len-v_totalOffset);
+    o_netAction->master = &(o_netAction->srvCmdAsw);
+  }
+
+  else if(v_cmd == NA_ping::ActionKey) {
+    o_netAction->ping = NA_ping(((char*)data)+v_totalOffset, len-v_totalOffset);
+    o_netAction->master = &(o_netAction->ping);
   }
 
   else {
@@ -313,8 +329,7 @@ NetAction* NetAction::newNetAction(void* data, unsigned int len) {
     throw Exception("net: invalid command");
   }
 
-  v_res->setSource(v_src, v_subsrc);
-  return v_res;
+  o_netAction->master->setSource(v_src, v_subsrc);
 }
 
 std::string NetAction::getLine(void* data, unsigned int len, unsigned int* o_local_offset) {
@@ -343,6 +358,17 @@ std::string NetAction::getLine(void* data, unsigned int len, unsigned int* o_loc
   return v_res;
 }
 
+std::string NetAction::getLineCheckUTF8(void* data, unsigned int len, unsigned int* o_local_offset) {
+  std::string v_res;
+
+  v_res = getLine(data, len, o_local_offset);
+  if(utf8::is_utf8_valid(v_res) == false) {
+    throw Exception("Invalid decoded strings (utf-8)");
+  }
+
+  return v_res;
+}
+
 void NetAction::send(TCPsocket* i_tcpsd, UDPsocket* i_udpsd, UDPpacket* i_sendPacket, IPaddress* i_udpRemoteIP) {
   NetAction::send(i_tcpsd, i_udpsd, i_sendPacket, i_udpRemoteIP, NULL, 0);
 }
@@ -359,6 +385,10 @@ NA_chatMessage::NA_chatMessage(void* data, unsigned int len) : NetAction(true) {
     ((char*)data)[len-1] = '\0';
     m_msg = std::string((char*)data);
     ((char*)data)[len-1] = '\n';
+
+    if(utf8::is_utf8_valid(m_msg) == false) {
+      throw Exception("Invalid decoded strings (utf-8)");
+    }
   }
 }
 
@@ -401,6 +431,10 @@ NA_chatMessagePP::NA_chatMessagePP(void* data, unsigned int len) : NetAction(tru
     ((char*)data)[len-1] = '\0';
     m_msg = std::string(((char*)data)+v_localOffset);
     ((char*)data)[len-1] = '\n';
+
+    if(utf8::is_utf8_valid(m_msg) == false) {
+      throw Exception("Invalid decoded strings (utf-8)");
+    }
   }
 }
 
@@ -439,6 +473,10 @@ NA_serverError::NA_serverError(void* data, unsigned int len) : NetAction(true) {
     ((char*)data)[len-1] = '\0';
     m_msg = std::string((char*)data);
     ((char*)data)[len-1] = '\n';
+
+    if(utf8::is_utf8_valid(m_msg) == false) {
+      throw Exception("Invalid decoded strings (utf-8)");
+    }
   }
 }
 
@@ -454,7 +492,9 @@ std::string NA_serverError::getMessage() {
 }
 
 NA_frame::NA_frame(SerializedBikeState* i_state) : NetAction(false) {
-  m_state = *i_state;
+  if(i_state != NULL) {
+    m_state = *i_state;
+  }
 }
 
 NA_frame::NA_frame(void* data, unsigned int len) : NetAction(false) {
@@ -541,7 +581,7 @@ NA_clientInfos::NA_clientInfos(void* data, unsigned int len) : NetAction(true) {
 
   /* since 2, client version string */
   if(m_protocolVersion >= 2) {
-    m_xmversion = getLine(((char*)data)+v_localOffset, len-v_localOffset, &v_localOffset);
+    m_xmversion = getLineCheckUTF8(((char*)data)+v_localOffset, len-v_localOffset, &v_localOffset);
   }
 }
 
@@ -576,7 +616,7 @@ NA_changeName::NA_changeName(const std::string& i_name) : NetAction(true) {
 
 NA_changeName::NA_changeName(void* data, unsigned int len) : NetAction(true) {
   unsigned int v_localOffset = 0;
-  m_name = getLine(data, len, &v_localOffset);
+  m_name = getLineCheckUTF8(data, len, &v_localOffset);
 }
 
 NA_changeName::~NA_changeName() {
@@ -590,13 +630,19 @@ std::string NA_changeName::getName() {
   return m_name;
 }
 
-NA_clientsNumber::NA_clientsNumber(int i_number) : NetAction(true) {
-  m_number = i_number;
+NA_clientsNumber::NA_clientsNumber(int i_ntcp, int i_nudp, int i_nghosts, int i_nslaves) : NetAction(true) {
+  m_ntcp    = i_ntcp;
+  m_nudp    = i_nudp;
+  m_nghosts = i_nghosts;
+  m_nslaves = i_nslaves;
 }
 
 NA_clientsNumber::NA_clientsNumber(void* data, unsigned int len) : NetAction(true) {
   unsigned int v_localOffset = 0;
-  m_number = atoi(getLine(data, len, &v_localOffset).c_str());
+  m_ntcp    = atoi(getLine(data, len, &v_localOffset).c_str());
+  m_nudp    = atoi(getLine(data, len, &v_localOffset).c_str());
+  m_nghosts = atoi(getLine(data, len, &v_localOffset).c_str());
+  m_nslaves = atoi(getLine(data, len, &v_localOffset).c_str());
 }
 
 NA_clientsNumber::~NA_clientsNumber() {
@@ -604,12 +650,27 @@ NA_clientsNumber::~NA_clientsNumber() {
 
 void NA_clientsNumber::send(TCPsocket* i_tcpsd, UDPsocket* i_udpsd, UDPpacket* i_sendPacket, IPaddress* i_udpRemoteIP) {
   std::ostringstream v_send;
-  v_send << m_number << "\n";
+  v_send << m_ntcp    << "\n";
+  v_send << m_nudp    << "\n";
+  v_send << m_nghosts << "\n";
+  v_send << m_nslaves;
   NetAction::send(i_tcpsd, NULL, NULL, NULL, v_send.str().c_str(), v_send.str().size()); // don't send the \0
 }
 
-int NA_clientsNumber::getNumber() {
-  return m_number;
+int NA_clientsNumber::getNumberTCP() const {
+  return m_ntcp;
+}
+
+int NA_clientsNumber::getNumberUDP() const {
+  return m_nudp;
+}
+
+int NA_clientsNumber::getNumberGhosts() const {
+  return m_nghosts;
+}
+
+int NA_clientsNumber::getNumberSlaves() const {
+  return m_nslaves;
 }
 
 NA_clientsNumberQuery::NA_clientsNumberQuery() : NetAction(true) {
@@ -631,7 +692,7 @@ NA_playingLevel::NA_playingLevel(const std::string& i_levelId) : NetAction(true)
 
 NA_playingLevel::NA_playingLevel(void* data, unsigned int len) : NetAction(true) {
   unsigned int v_localOffset = 0;
-  m_levelId = getLine(data, len, &v_localOffset);
+  m_levelId = getLineCheckUTF8(data, len, &v_localOffset);
 }
 
 NA_playingLevel::~NA_playingLevel() {
@@ -662,7 +723,7 @@ NA_changeClients::NA_changeClients(void* data, unsigned int len) : NetAction(tru
     v_infosClient.NetId = atoi(getLine(((char*)data)+v_localOffset, len-v_localOffset, &v_localOffset).c_str());
 
     if(v_symbol == "+") {
-      v_infosClient.Name  = getLine(((char*)data)+v_localOffset, len-v_localOffset, &v_localOffset);
+      v_infosClient.Name  = getLineCheckUTF8(((char*)data)+v_localOffset, len-v_localOffset, &v_localOffset);
       m_netAddedInfosClients.push_back(v_infosClient);
     } else if(v_symbol == "-") {
       m_netRemovedInfosClients.push_back(v_infosClient);
@@ -682,7 +743,7 @@ void NA_changeClients::remove(NetInfosClient* i_infoClient) {
 }
 
 void NA_changeClients::send(TCPsocket* i_tcpsd, UDPsocket* i_udpsd, UDPpacket* i_sendPacket, IPaddress* i_udpRemoteIP) {
-  std::ostringstream v_send;  
+  std::ostringstream v_send;
 
   for(unsigned int i=0; i<m_netAddedInfosClients.size(); i++) {
     v_send << "+" << "\n";
@@ -796,7 +857,7 @@ NA_prepareToPlay::NA_prepareToPlay(void* data, unsigned int len) : NetAction(tru
   unsigned int v_localOffset = 0;
   unsigned int v_nplayers;
 
-  m_id_level = getLine(((char*)data)+v_localOffset, len-v_localOffset, &v_localOffset);
+  m_id_level = getLineCheckUTF8(((char*)data)+v_localOffset, len-v_localOffset, &v_localOffset);
   v_nplayers = atoi(getLine(((char*)data)+v_localOffset, len-v_localOffset, &v_localOffset).c_str());
   for(unsigned int i=0; i<v_nplayers; i++) {
     m_players.push_back(atoi(getLine(((char*)data)+v_localOffset, len-v_localOffset, &v_localOffset).c_str()));
@@ -873,7 +934,11 @@ int NA_prepareToGo::time() const {
 }
 
 NA_gameEvents::NA_gameEvents(DBuffer* i_buffer) : NetAction(true) {
-  m_bufferLength = i_buffer->copyTo(m_buffer, XM_NET_MAX_EVENTS_SHOT_SIZE);
+  if(i_buffer == NULL) {
+    m_bufferLength = 0;
+  } else {
+    m_bufferLength = i_buffer->copyTo(m_buffer, XM_NET_MAX_EVENTS_SHOT_SIZE);
+  }
 }
 
 NA_gameEvents::NA_gameEvents(void* data, unsigned int len) : NetAction(true) {
@@ -906,6 +971,10 @@ NA_srvCmd::NA_srvCmd(void* data, unsigned int len) : NetAction(true) {
     ((char*)data)[len-1] = '\0';
     m_cmd = std::string((char*)data);
     ((char*)data)[len-1] = '\n';
+
+    if(utf8::is_utf8_valid(m_cmd) == false) {
+      throw Exception("Invalid decoded strings (utf-8)");
+    }
   }
 }
 
@@ -929,6 +998,10 @@ NA_srvCmdAsw::NA_srvCmdAsw(void* data, unsigned int len) : NetAction(true) {
     ((char*)data)[len-1] = '\0';
     m_answer = std::string((char*)data);
     ((char*)data)[len-1] = '\n';
+
+    if(utf8::is_utf8_valid(m_answer) == false) {
+      throw Exception("Invalid decoded strings (utf-8)");
+    }
   }
 }
 
@@ -942,3 +1015,91 @@ void NA_srvCmdAsw::send(TCPsocket* i_tcpsd, UDPsocket* i_udpsd, UDPpacket* i_sen
 std::string NA_srvCmdAsw::getAnswer() {
   return m_answer;
 }
+
+NA_slaveClientsPoints::NA_slaveClientsPoints() : NetAction(true) {
+}
+
+NA_slaveClientsPoints::NA_slaveClientsPoints(void* data, unsigned int len) : NetAction(true) {
+  unsigned int v_localOffset = 0;
+  NetPointsClient v_pointsClient;
+
+  if(len == 1) { // no client (only \n)
+    return;
+  }
+
+  while(v_localOffset < len) {
+    v_pointsClient.NetId  = atoi(getLine(((char*)data)+v_localOffset, len-v_localOffset, &v_localOffset).c_str());
+    v_pointsClient.Points = atoi(getLine(((char*)data)+v_localOffset, len-v_localOffset, &v_localOffset).c_str());
+    m_netPointsClients.push_back(v_pointsClient);
+  }
+}
+
+NA_slaveClientsPoints::~NA_slaveClientsPoints() {
+}
+
+void NA_slaveClientsPoints::send(TCPsocket* i_tcpsd, UDPsocket* i_udpsd, UDPpacket* i_sendPacket, IPaddress* i_udpRemoteIP) {
+  std::ostringstream v_send;
+
+  for(unsigned int i=0; i<m_netPointsClients.size(); i++) {
+    v_send << m_netPointsClients[i].NetId  << "\n";
+    v_send << m_netPointsClients[i].Points << "\n";
+  }
+
+  if(m_netPointsClients.size() > 0) {
+    NetAction::send(i_tcpsd, NULL, NULL, NULL, v_send.str().c_str(), v_send.str().size()-1); // don't send the \0 and the last \n
+  } else {
+    NetAction::send(i_tcpsd, NULL, NULL, NULL, v_send.str().c_str(), v_send.str().size()); // don't send the \0
+  }
+}
+
+const std::vector<NetPointsClient>& NA_slaveClientsPoints::getPointsClients() const {
+  return m_netPointsClients;
+}
+
+void NA_slaveClientsPoints::add(NetPointsClient* i_npc) {
+  m_netPointsClients.push_back(*i_npc);
+}
+
+//
+// ping / pong
+//
+
+int NA_ping::m_currentId = 5;
+
+NA_ping::NA_ping(NA_ping* i_ping) : NetAction(false) {
+  if(i_ping == NULL) {
+    m_isPong   = false;
+    m_id       = m_currentId++;
+  } else {
+    m_isPong = true;
+    m_id     = i_ping->m_id;
+  }
+}
+
+NA_ping::NA_ping(void* data, unsigned int len) : NetAction(false) {
+  unsigned int v_localOffset = 0;
+
+  m_isPong = atoi(getLine(((char*)data)+v_localOffset, len-v_localOffset, &v_localOffset).c_str()) == 1;
+  m_id     = atoi(getLine(((char*)data)+v_localOffset, len-v_localOffset, &v_localOffset).c_str());
+}
+
+NA_ping::~NA_ping() {
+}
+
+void NA_ping::send(TCPsocket* i_tcpsd, UDPsocket* i_udpsd, UDPpacket* i_sendPacket, IPaddress* i_udpRemoteIP) {
+  std::ostringstream v_send;
+  int n = m_isPong ? 1:0;
+
+  v_send << n << "\n";
+  v_send << m_id;
+
+  NetAction::send(i_tcpsd, NULL, NULL, NULL, v_send.str().c_str(), v_send.str().size()); // don't send the \0
+}
+
+int NA_ping::id() const {
+  return m_id;
+}
+
+bool NA_ping::isPong() const {
+  return m_isPong;
+}
