@@ -40,24 +40,59 @@ public:
 		  bool drawStateBehind    = true,
 		  bool updateStatesBehind = false,
 		  bool i_verticallyLarge = false);
+  StateMessageBox(StateMessageBoxReceiver* i_receiver,
+		  std::vector<std::string>& completionList,
+  		  const std::string& i_text,
+  		  int i_buttons,
+  		  bool i_input = false,
+  		  const std::string& i_inputText = "",
+  		  bool i_query = false,
+  		  bool drawStateBehind    = true,
+  		  bool updateStatesBehind = false,
+  		  bool i_verticallyLarge = false);
   virtual ~StateMessageBox();
 
+  virtual void enter();
   virtual void leave();
 
+  std::string getMsgBxId() const;
+  void setMsgBxId(const std::string& i_id);
+
   /* input */
   virtual void xmKey(InputEventType i_type, const XMKey& i_xmkey);
   void makeActiveButton(UIMsgBoxButton i_button);
+  void setCustom(const std::string& i_custom1, const std::string& i_custom2 = "");
+  void setHelp(const std::string& i_help);
 
 protected:
   virtual void checkEvents();
 
 private:
+  void initStateMessageBox(StateMessageBoxReceiver* i_receiver,
+			   const std::string& i_text,
+			   int i_buttons,
+			   bool i_input,
+			   const std::string& i_inputText,
+			   bool i_query,
+			   bool i_verticallyLarge);
+
   UIMsgBox* m_msgbox;
   StateMessageBoxReceiver* m_receiver;
   UIMsgBoxButton m_clickedButton;
+  std::string m_msgbxid;
 
-  void createGUI(const std::string& i_text, int i_buttons,
-		 bool i_input, const std::string& i_inputText, bool i_query, bool i_verticallyLarge);
+  void createGUI();
+
+  // requirement to build the msgbox. Note that it's not directly done in the constructor while it's forbiden to use the XMScreen into the constructor (set after)
+  std::string m_text;
+  int m_buttons;
+  bool m_input;
+  std::string m_inputText;
+  bool m_query;
+  bool m_verticallyLarge;
+  std::vector<std::string> m_completionList;
+  std::string m_custom1, m_custom2;
+  std::string m_help;
 };
 
 #endif
