@@ -22,12 +22,12 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #define __STATEMESSAGEBOXRECEIVER_H__
 
 #include <string>
-#include "gui/basic/GUI.h"
+#include "../gui/basic/GUI.h"
 
 class StateMessageBoxReceiver {
   public:
   virtual ~StateMessageBoxReceiver() {};
-  virtual void send(const std::string& i_id, UIMsgBoxButton i_button, const std::string& i_input) = 0;
+  virtual void sendFromMessageBox(const std::string& i_id, UIMsgBoxButton i_button, const std::string& i_input) = 0;
 };
 
 #endif
