@@ -74,7 +74,7 @@ protected:
 private:
   /* GUI */
   static UIRoot* m_sGUI;
-  static void createGUIIfNeeded();
+  static void createGUIIfNeeded(RenderSurface* i_screen);
 
   void init();
 };
