@@ -49,7 +49,9 @@ void StatePreplayingNet::abortPlaying() {
   StateScene::abortPlaying();
 
   if(NetClient::instance()->isConnected()) {
-    NetClient::instance()->disconnect();
+    /* switch ghost mode */
+    XMSession::instance()->setClientGhostMode(NETCLIENT_GHOST_MODE);
+    NetClient::instance()->changeMode(XMSession::instance()->clientGhostMode() ? NETCLIENT_GHOST_MODE : NETCLIENT_SLAVE_MODE);
   }
 }
 
@@ -71,7 +73,8 @@ void StatePreplayingNet::initPlayers() {
   v_world->getCamera()->setPlayerToFollow(
 		  v_world->addPlayerNetClient(v_world->getLevelSrc()->PlayerStart(), DD_RIGHT,
 					      Theme::instance(), Theme::instance()->getPlayerTheme(),
-					      pGame->getColorFromPlayerNumber(0), pGame->getUglyColorFromPlayerNumber(0)));
+					      pGame->getColorFromPlayerNumber(0), pGame->getUglyColorFromPlayerNumber(0),
+					      true));
   v_world->getCamera()->setScroll(false, v_world->getGravity());
 }
 
