@@ -278,21 +278,23 @@ bool StateScene::render()
     }
 
     // downloading ghost information
-    if(m_universe->waitingForGhosts()) {
-      FontManager* v_fm = GameApp::instance()->getDrawLib()->getFontSmall();
-      FontGlyph* v_fg   = v_fm->getGlyph(GAMETEXT_DLGHOSTS);
-      int v_border = 5;
+    if(m_universe != NULL) {
+      if(m_universe->waitingForGhosts()) {
+	FontManager* v_fm = GameApp::instance()->getDrawLib()->getFontSmall();
+	FontGlyph* v_fg   = v_fm->getGlyph(GAMETEXT_DLGHOSTS);
+	int v_border = 5;
 
-      GameApp::instance()->getDrawLib()->drawBox(Vector2f(m_screen.getDispWidth()/2 - v_fg->realWidth()/2 -v_border,
-							  m_screen.getDispHeight() - v_fg->realHeight() - 2*v_border),
-						 Vector2f(m_screen.getDispWidth()/2 + v_fg->realWidth()/2 + v_border,
-							  m_screen.getDispHeight() + v_border),
-						 0.0f, MAKE_COLOR(255,255,255,50));
-
-      v_fm->printString(GameApp::instance()->getDrawLib(), v_fg,
-			m_screen.getDispWidth()/2 - v_fg->realWidth()/2,
-			m_screen.getDispHeight() - v_fg->realHeight() - v_border,
-			MAKE_COLOR(255,255,255,255), 0.0, true);
+	GameApp::instance()->getDrawLib()->drawBox(Vector2f(m_screen.getDispWidth()/2 - v_fg->realWidth()/2 -v_border,
+							    m_screen.getDispHeight() - v_fg->realHeight() - 2*v_border),
+						   Vector2f(m_screen.getDispWidth()/2 + v_fg->realWidth()/2 + v_border,
+							    m_screen.getDispHeight() + v_border),
+						   0.0f, MAKE_COLOR(255,255,255,50));
+	
+	v_fm->printString(GameApp::instance()->getDrawLib(), v_fg,
+			  m_screen.getDispWidth()/2 - v_fg->realWidth()/2,
+			  m_screen.getDispHeight() - v_fg->realHeight() - v_border,
+			  MAKE_COLOR(255,255,255,255), 0.0, true);
+      }
     }
 
 
@@ -310,16 +312,18 @@ void StateScene::onRenderFlush() {
   // take a screenshot
   if(XMSession::instance()->enableVideoRecording()) {
     if(StateManager::instance()->getVideoRecorder() != NULL) {
-      if(m_universe->getScenes().size() > 0) {
-	if( (XMSession::instance()->videoRecordingStartTime() < 0 ||
-	     XMSession::instance()->videoRecordingStartTime() <= m_universe->getScenes()[0]->getTime()
-	     )
-	    &&
-	    (XMSession::instance()->videoRecordingEndTime() < 0 ||
-	     XMSession::instance()->videoRecordingEndTime() >= m_universe->getScenes()[0]->getTime()
-	     )
-	    ) {
-	  StateManager::instance()->getVideoRecorder()->read(m_universe->getScenes()[0]->getTime());
+      if(m_universe != NULL) {
+	if(m_universe->getScenes().size() > 0) {
+	  if( (XMSession::instance()->videoRecordingStartTime() < 0 ||
+	       XMSession::instance()->videoRecordingStartTime() <= m_universe->getScenes()[0]->getTime()
+	       )
+	      &&
+	      (XMSession::instance()->videoRecordingEndTime() < 0 ||
+	       XMSession::instance()->videoRecordingEndTime() >= m_universe->getScenes()[0]->getTime()
+	       )
+	      ) {
+	    StateManager::instance()->getVideoRecorder()->read(m_universe->getScenes()[0]->getTime());
+	  }
 	}
       }
     }
@@ -414,7 +418,7 @@ void StateScene::xmKey(InputEventType i_type, const XMKey& i_xmkey) {
   }
   
   
-  else if(i_type == INPUT_DOWN && i_xmkey == XMKey(SDLK_n, KMOD_LCTRL)) {
+  else if(i_type == INPUT_DOWN && i_xmkey == (*InputHandler::instance()->getGlobalKey(INPUT_SWITCHHIGHSCOREINFORMATION))) {
     if(m_renderer != NULL) {
       if(XMSession::instance()->showHighscoreInGame() == false){
 	XMSession::instance()->setShowHighscoreInGame(true);	
@@ -618,22 +622,23 @@ void StateScene::setScoresTimes() {
     if(XMSession::instance()->showHighscoreInGame() && XMSession::instance()->hidePlayingInformation() == false) {
 
       std::string v_nextMedal;
+      std::string v_author;
       int         v_nextMedal_time;
       bool        v_isNextMedal;
 
       if(XMSession::instance()->nbRoomsEnabled() >= 1) {
 	std::string v_best_str;
-	v_best_str = GameApp::instance()->getWorldRecord(0, v_id_level, v_best_room_time);
+	v_best_str = GameApp::instance()->getWorldRecord(0, v_id_level, v_best_room_time, v_author);
       }
 
-      v_isNextMedal = GameApp::instance()->getNextMedal(v_best_room_time, v_best_player_time, v_nextMedal, v_nextMedal_time);
+      v_isNextMedal = GameApp::instance()->getNextMedal(XMSession::instance()->profile(), v_author, v_best_room_time, v_best_player_time, v_nextMedal, v_nextMedal_time);
 
       /* won't next medal, or next medal doesn't exist */
       if(XMSession::instance()->showNextMedalInGame() == false || v_isNextMedal == false) {
 	std::string v_strWorldRecord;
 	int v_best_time;
 	for(unsigned int i=0; i<XMSession::instance()->nbRoomsEnabled(); i++) {
-	  v_strWorldRecord += GameApp::instance()->getWorldRecord(i, v_id_level, v_best_time) + "\n";
+	  v_strWorldRecord += GameApp::instance()->getWorldRecord(i, v_id_level, v_best_time, v_author) + "\n";
 	}
 	m_renderer->setWorldRecordTime(v_strWorldRecord);
       } else {
@@ -666,6 +671,7 @@ void StateScene::closePlaying() {
   if(m_renderer != NULL) {
     m_renderer->unprepareForNewLevel(m_universe);
     delete m_renderer;
+    m_renderer = NULL;
   }
 
   if(m_universe != NULL) {
@@ -810,12 +816,16 @@ void StateScene::executeOneCommand(std::string cmd, std::string args)
   }
 
   else if(cmd == "REPLAY_DOWNLOADED") {
-    m_universe->markDownloadedGhost(args, true);
+    if(m_universe != NULL) {
+      m_universe->markDownloadedGhost(args, true);
+    }
   }
 
   else if(cmd == "REPLAY_FAILEDTODOWNLOAD") {
     /* remove it from the waiting replays to be downloaded */
-    m_universe->markDownloadedGhost(args, false);
+    if(m_universe != NULL) {
+      m_universe->markDownloadedGhost(args, false);
+    }
   }
 
   else {
