@@ -18,9 +18,9 @@ along with XMOTO; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 =============================================================================*/
 
-#include "GameText.h"
+#include "../GameText.h"
 #include "StateUpdateRoomsList.h"
-#include "thread/UpdateRoomsListThread.h"
+#include "../thread/UpdateRoomsListThread.h"
 
 StateUpdateRoomsList::StateUpdateRoomsList(bool drawStateBehind,
 					   bool updateStatesBehind)
