@@ -19,7 +19,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 =============================================================================*/
 
 #include "StateUploadAllHighscores.h"
-#include "thread/UploadAllHighscoresThread.h"
+#include "../thread/UploadAllHighscoresThread.h"
 
 StateUploadAllHighscores::StateUploadAllHighscores(unsigned int i_number,
 						   bool drawStateBehind,
