@@ -31,7 +31,8 @@ enum EntitySpeciality {
   ET_KILL     	      = 4,
   ET_ISTOTAKE 	      = 5,
   ET_PARTICLES_SOURCE = 6,
-  ET_JOINT            = 7
+  ET_JOINT            = 7,
+  ET_CHECKPOINT	      = 8
 };
 
 /*===========================================================================
