@@ -1,6 +1,5 @@
 /*=============================================================================
 XMOTO
-Copyright (C) 2005-2006 Rasmus Neckelmann (neckelmann@gmail.com)
 
 This file is part of XMOTO.
 
@@ -28,7 +27,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 class BikeAnchors {
   public:
   Vector2f GroundPoint() const;
-  void update(const BikeParameters &i_bikeParameters);
+  void update(BikeParameters* i_bikeParameters);
 
   //  private:
   Vector2f Tp;          /* Point on the ground, exactly between the wheels */
