@@ -30,10 +30,11 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #define INTERPOLATION_MAXIMUM_SPACE 5.0
 
 Ghost::Ghost(PhysicsSettings* i_physicsSettings,
+	     bool i_engineSound,
 	     Theme *i_theme, BikerTheme* i_bikerTheme,
 	     const TColor& i_colorFilter,
 	     const TColor& i_uglyColorFilter)
-: Biker(i_physicsSettings, i_theme, i_bikerTheme, i_colorFilter, i_uglyColorFilter) {
+: Biker(i_physicsSettings, i_engineSound, i_theme, i_bikerTheme, i_colorFilter, i_uglyColorFilter) {
   m_diffToPlayer = 0.0;
   m_reference = false;
 }
@@ -62,27 +63,18 @@ void Ghost::setInfo(const std::string& i_info) {
 }
 
 FileGhost::FileGhost(std::string i_replayFile, PhysicsSettings* i_physicsSettings,
-	     bool i_isActiv,
-	     Theme *i_theme, BikerTheme* i_bikerTheme,
-	     const TColor& i_colorFilter,
-	     const TColor& i_uglyColorFilter)
-  : Ghost (i_physicsSettings, i_theme, i_bikerTheme, i_colorFilter, i_uglyColorFilter) {
+		     bool i_isActiv,
+		     bool i_engineSound,
+		     Theme *i_theme, BikerTheme* i_bikerTheme,
+		     const TColor& i_colorFilter,
+		     const TColor& i_uglyColorFilter)
+: Ghost (i_physicsSettings, i_engineSound, i_theme, i_bikerTheme, i_colorFilter, i_uglyColorFilter) {
   std::string v_levelId;
   std::string v_playerName;
 
   m_replay = new Replay();
   v_levelId = m_replay->openReplay(i_replayFile, v_playerName);
 
-  
-  
-  // all states for Ghost Trail
-  unsigned int i=0;
-  while( !m_replay->endOfFile()) {
-    m_allGhostBikeStates.push_back(new BikeState(m_physicsSettings));
-    m_replay->loadState(m_allGhostBikeStates[i], m_physicsSettings);
-    i++;
-  }
-  
   // 4 states for cubical interpolation
 
   // 50% of states are before the time T, 50% are after
@@ -95,21 +87,17 @@ FileGhost::FileGhost(std::string i_replayFile, PhysicsSettings* i_physicsSetting
   for(unsigned int i=0; i<m_ghostBikeStates.size(); i++) {
     m_replay->peekState(m_ghostBikeStates[i], m_physicsSettings);
   }
-  *m_bikeState = *(m_allGhostBikeStates[0]); // copy
+  *m_bikeState = *(m_ghostBikeStates[0]); // copy
 
   m_isActiv = i_isActiv;
   m_linearVelocity = 0.0;
   m_teleportationOccured = false;
-  
 }
 
 FileGhost::~FileGhost() {
   for(unsigned int i=0; i<m_ghostBikeStates.size(); i++) {
     delete m_ghostBikeStates[i];
   }
-  for(unsigned int i=0; i<m_allGhostBikeStates.size(); i++) {
-    delete m_allGhostBikeStates[i];
-  }
 }
 
 void FileGhost::execReplayEvents(int i_time, Scene *i_motogame) {
@@ -141,6 +129,57 @@ void FileGhost::execReplayEvents(int i_time, Scene *i_motogame) {
       (*v_replayEvents)[i]->bPassed = false;
     }
   }
+
+  // apply moving blocks
+  std::vector<rmtime>* v_mb = m_replay->getMovingBlocks();
+  for(unsigned int i=0; i<v_mb->size(); i++) {
+    // reference the block
+    if((*v_mb)[i].block == NULL) {
+      (*v_mb)[i].block = i_motogame->getLevelSrc()->getBlockById((*v_mb)[i].name);
+    }
+
+    //
+    if((*v_mb)[i].states.size() > 0) {
+
+      // continue to read the time
+      while((*v_mb)[i].states[(*v_mb)[i].readPos].time < i_time) {
+	(*v_mb)[i].readPos++;
+      }
+
+      // not at the end
+      if((*v_mb)[i].readPos < (*v_mb)[i].states.size()) {
+	// and time is found
+	if((*v_mb)[i].states[(*v_mb)[i].readPos].time == i_time) {
+	  // apply the state
+	  i_motogame->SetBlockPos((*v_mb)[i].block,
+				  (*v_mb)[i].states[(*v_mb)[i].readPos].position.x,
+				  (*v_mb)[i].states[(*v_mb)[i].readPos].position.y);
+	  i_motogame->SetBlockRotation((*v_mb)[i].block, (*v_mb)[i].states[(*v_mb)[i].readPos].rotation);
+	} else {
+	  // interpolation
+	  if(m_doInterpolation) {
+	    // ok between frame 2 and n-1
+	    if((*v_mb)[i].readPos > 0) {
+	      float pertime = 
+		((float)(i_time - (*v_mb)[i].states[(*v_mb)[i].readPos-1].time)) /
+		((float)((*v_mb)[i].states[(*v_mb)[i].readPos].time - (*v_mb)[i].states[(*v_mb)[i].readPos-1].time));
+	      
+	      float new_pos_x = (*v_mb)[i].states[(*v_mb)[i].readPos-1].position.x +
+		((*v_mb)[i].states[(*v_mb)[i].readPos].position.x - (*v_mb)[i].states[(*v_mb)[i].readPos-1].position.x)*pertime;
+	      
+	      float new_pos_y = (*v_mb)[i].states[(*v_mb)[i].readPos-1].position.y +
+		((*v_mb)[i].states[(*v_mb)[i].readPos].position.y - (*v_mb)[i].states[(*v_mb)[i].readPos-1].position.y)*pertime;
+
+	      float new_pos_r = interpolateAngle((*v_mb)[i].states[(*v_mb)[i].readPos-1].rotation, (*v_mb)[i].states[(*v_mb)[i].readPos].rotation, pertime);
+
+	      i_motogame->SetBlockPos((*v_mb)[i].block, new_pos_x, new_pos_y);
+	      i_motogame->SetBlockRotation((*v_mb)[i].block, new_pos_r);
+	    }
+	  }
+	}
+      }
+    }
+  }
 }
 
 std::string FileGhost::getDescription() const {
@@ -258,6 +297,7 @@ void FileGhost::updateToTime(int i_time, int i_timeStep,
     // m_ghostBikeStates.size()/2 : first state in the feature
     if(m_ghostBikeStates[m_ghostBikeStates.size()/2]->GameTime < i_time) {
       
+      bool v_didRead = false;
       do {
 	// move the bikestates
 	v_state = m_ghostBikeStates[0];
@@ -269,14 +309,14 @@ void FileGhost::updateToTime(int i_time, int i_timeStep,
 	if(m_replay->endOfFile()) {
 	  // copy n-1 to n
 	  *(m_ghostBikeStates[m_ghostBikeStates.size()-1]) = *(m_ghostBikeStates[m_ghostBikeStates.size()-1-1]);
+	  v_didRead = false;
 	} else {
 	  // read the replay
 	  m_replay->loadState(m_ghostBikeStates[m_ghostBikeStates.size()-1], m_physicsSettings);
 	  m_replay->loadState(m_bikeState, m_physicsSettings);
+	  v_didRead = true;
 	}
-
-      } while(m_ghostBikeStates[m_ghostBikeStates.size()/2]->GameTime < i_time &&
-	      m_ghostBikeStates[m_ghostBikeStates.size()/2]->GameTime > m_ghostBikeStates[m_ghostBikeStates.size()/2-1]->GameTime);
+      } while(m_ghostBikeStates[m_ghostBikeStates.size()/2]->GameTime < i_time && v_didRead);
 
 
       *m_bikeState = *(m_ghostBikeStates[m_ghostBikeStates.size()/2-1]); // copy
@@ -286,8 +326,10 @@ void FileGhost::updateToTime(int i_time, int i_timeStep,
       v_afterPos   = m_ghostBikeStates[m_ghostBikeStates.size()/2]->CenterP;
       v_afterTime  = m_ghostBikeStates[m_ghostBikeStates.size()/2]->GameTime;
       
-      // warning, absolutly no idea why * 10.0, but it is needed to work...
-      m_linearVelocity = (Vector2f(v_afterPos - v_beforePos)).length() * 10.0 / (v_afterTime - v_beforeTime);
+      // warning, absolutly no idea why * 2.0, but it is needed to work... (*100 because hundreadths, *3.6 for km/h)
+      if(v_afterTime - v_beforeTime > 0) {
+	m_linearVelocity = (Vector2f(v_afterPos - v_beforePos)).length()*100.0*3.6*2.0 / ((float)(v_afterTime - v_beforeTime));
+      }
 
     } else { /* interpolation */
       /* do interpolation if it doesn't seems to be a teleportation or something like that */
@@ -355,12 +397,12 @@ double FileGhost::getAngle() {
   return 0.0; /* to do */
 }
 
-
 NetGhost::NetGhost(PhysicsSettings* i_physicsSettings,
+		   bool i_engineSound,
 		   Theme *i_theme, BikerTheme* i_bikerTheme,
 		   const TColor& i_colorFilter,
 		   const TColor& i_uglyColorFilter) 
-  : Ghost(i_physicsSettings, i_theme, i_bikerTheme, i_colorFilter, i_uglyColorFilter) {
+: Ghost(i_physicsSettings, i_engineSound, i_theme, i_bikerTheme, i_colorFilter, i_uglyColorFilter) {
 }
 
 NetGhost::~NetGhost() {
@@ -402,8 +444,9 @@ double NetGhost::getAngle() {
 }
 
 ReplayBiker::ReplayBiker(std::string i_replayFile, PhysicsSettings* i_physicsSettings,
+			 bool i_engineSound,
 			 Theme *i_theme, BikerTheme* i_bikerTheme)
-:FileGhost(i_replayFile, i_physicsSettings, true, i_theme, i_bikerTheme,
+:FileGhost(i_replayFile, i_physicsSettings, true, i_engineSound, i_theme, i_bikerTheme,
        TColor(255, 255, 255, 0),
        TColor(GET_RED(i_bikerTheme->getUglyRiderColor()),
 	      GET_GREEN(i_bikerTheme->getUglyRiderColor()),
