@@ -22,9 +22,10 @@
 #include "../Game.h"
 #include "Bike.h"
 #include "BikeGhost.h"
-#include "helpers/Log.h"
+#include "../helpers/Log.h"
 #include <sstream>
 #include "../SysMessage.h"
+#include "../drawlib/DrawLib.h"
 
 #define ZOOM_DEFAULT 0.24
 #define ZOOM_DEFAULT_NO_AUTOZOOM 0.195
@@ -56,19 +57,21 @@
 #define TRAILCAM_DAMPING 0.01   // smaller damps more
 
 #ifdef ENABLE_OPENGL
-#include "include/xm_OpenGL.h"
+#include "../include/xm_OpenGL.h"
 #endif
 
-Camera::Camera(Vector2i upperleft, Vector2i downright){
+Camera::Camera(Vector2i downleft, Vector2i upright){
   m_fScale         = ZOOM_DEFAULT;
   m_cameraOffsetX  = CAMERA_OFFSETX_DEFAULT;
   m_cameraOffsetY  = CAMERA_OFFSETY_DEFAULT;
   m_playerToFollow = NULL;
-  setRenderSurface(upperleft, downright);
+  setRenderSurface(downleft, upright);
   m_mirrored = false;
-  m_allowActiveZoom = true;
+  m_allowActiveZoom = false;
   m_cameraDeathOffset = Vector2f(0.0, 0.0);
   m_ghostTrail = NULL;
+  m_trailAvailable = false;
+  m_useTrailCam = false;
   prepareForNewLevel();
 }
 
@@ -87,12 +90,9 @@ void Camera::prepareForNewLevel() {
   setScroll(false, Vector2f(0, -9.81));
   resetActiveZoom();
   initActiveZoom();
-  //trail stuff
-  m_trailAvailable = false;
-  m_ghostTrail = NULL;
-  m_trackingShotActivated = false;
-  m_catchTrail = false;
-  m_trailCamForwardSteps = 0;
+  m_nShadeTime = GameApp::getXMTime();
+  m_doShade = false;
+  m_doShadeAnim = false;
 }
 
 void Camera::resetActiveZoom()
@@ -152,30 +152,38 @@ void Camera::initCamera() {
   initZoom();
 }
 
-void Camera::initTrailCam(Scene* i_scene) {
-  GhostTrail* v_ghostTrail = i_scene->getGhostTrail();
-  if( v_ghostTrail != NULL ) {
-    m_ghostTrail =  v_ghostTrail; 
-    m_trailAvailable = i_scene->getGhostTrail()->getGhostTrailAvailable(); 
-    if(m_ghostTrail != 0){
-       m_trailAvailable = true;
-    }
-    else {
-      m_trailAvailable = false;
-      return;
-    }
+void Camera::setUseTrailCam(bool i_value) {
+  m_useTrailCam = i_value;
+
+  if(m_useTrailCam == false && m_trailAvailable) {
+    m_catchTrail = false;
+    initCameraPosition();
   }
- 
+}
+
+void Camera::initTrailCam(GhostTrail* i_ghostTrail) {
+  if(i_ghostTrail == NULL) {
+    m_trailAvailable = false;
+    m_ghostTrail = NULL;
+    return;
+  }
+
+  m_trailAvailable = true;
+  m_ghostTrail =  i_ghostTrail; 
+  m_trailAvailable = i_ghostTrail->getGhostTrailAvailable(); 
   m_currentNearestTrailDataPosition = 0;
   m_trackShotIndex = 0;
   m_trackShotStartIndex = 0;
   m_dampVectorMax = Vector2f(m_cameraOffsetX,m_cameraOffsetY);
   m_dampCurrent = Vector2f(m_cameraOffsetX,m_cameraOffsetY);
+
+  m_trackingShotActivated = false;
+  m_catchTrail = false;
+  m_trailCamForwardSteps = 0;
 }
 
 Vector2f Camera::updateTrailCam() {
   if( m_useTrailCam && m_catchTrail && m_trailAvailable ) {
-  
     //calculate how many forward steps depending from player speed
     m_trailCamForwardSteps = int(m_playerToFollow->getBikeLinearVel() * 0.4) + TRAILCAM_MIN_FORWARDSTEPS;
     if(m_trailCamForwardSteps > TRAILCAM_MAX_FORWARDSTEPS) m_trailCamForwardSteps = TRAILCAM_MAX_FORWARDSTEPS;
@@ -261,37 +269,20 @@ void Camera::trailCamTrackingShot() {
   }
 }
 
-void Camera::toggleTrackingShot(Scene *i_scene) {
-  if(m_trackingShotActivated) { 
-    m_trackingShotActivated = false;
-    XMSession::instance()->setRenderGhostTrailTS(false);
-    initCameraPosition();
-    i_scene->pause();
-  }
-  else {
-    XMSession::instance()->setRenderGhostTrailTS(true);
-    i_scene->pause();
-    m_trackingShotActivated = true;
+bool Camera::useTrackingShot() const {
+  return m_trackingShotActivated;
+}
+
+void Camera::setUseTrackingShot(bool i_value) {
+  m_trackingShotActivated = i_value;
+  initCameraPosition();
+
+  if(m_trackingShotActivated == false) {
     m_trackShotStartIndex = locateNearestPointOnInterpolatedTrail(false);  //test true here
     m_trackShotIndex = m_trackShotStartIndex;
   }
 }
 
-void Camera::toggleTrailCam() {
- if(m_useTrailCam && m_trailAvailable) {
-   XMSession::instance()->setEnableTrailCam(false);
-   m_useTrailCam = false;
-   m_catchTrail = false;
-   initCameraPosition();
- }
- else if(m_trailAvailable){
-   XMSession::instance()->setEnableTrailCam(true);
-   m_useTrailCam = true; 
- }
-}
-
-
-
 unsigned int Camera::locateNearestPointOnInterpolatedTrail(bool i_optimize) {
   // delivers the position index for m_trailData for the nearest trailpoint to camera
  
@@ -453,12 +444,22 @@ void Camera::guessDesiredCameraZoom() {
   }
 }
 
+void Camera::setPlayerResussite() { // opposite of setPlayerDead
+  m_cameraDeathOffset = Vector2f(0.0, 0.0);
+
+  //remove shadow
+  setScreenShade(false, false);  
+}
+
 void Camera::setPlayerDead() {
   if(m_playerToFollow->getState()->Dir == DD_RIGHT) {
     m_cameraDeathOffset = m_playerToFollow->getState()->CenterP - m_playerToFollow->getState()->KneeP;
   } else {
     m_cameraDeathOffset = m_playerToFollow->getState()->CenterP - m_playerToFollow->getState()->Knee2P;
   }
+  //apply shadow
+  setShadeTime(GameApp::getXMTime());
+  setScreenShade(true,true);
 }
 
 void Camera::setScroll(bool isSmooth, const Vector2f& gravity) { 
@@ -591,10 +592,15 @@ Biker* Camera::getPlayerToFollow() {
   return m_playerToFollow;
 }
 
+void Camera::activate() {
+  DrawLib* drawLib = GameApp::instance()->getDrawLib();
+  drawLib->setRenderSurface(&m_renderSurf);
+}
+
 void Camera::setCamera2d() {
 #ifdef ENABLE_OPENGL
-  glViewport(m_renderSurf.upperleft().x, m_renderSurf.upperleft().y,
-	     m_renderSurf.size().x,      m_renderSurf.size().y);						 
+  glViewport(m_renderSurf.downleft().x, m_renderSurf.downleft().y,
+  	     m_renderSurf.size().x, m_renderSurf.size().y);
   glMatrixMode(GL_PROJECTION);
   glLoadIdentity();
   glOrtho(0, m_renderSurf.size().x,
@@ -603,21 +609,25 @@ void Camera::setCamera2d() {
   glMatrixMode(GL_MODELVIEW);
   glLoadIdentity();
 #endif
+
+  activate();
 }
 
 void Camera::setCamera3d(){
 #ifdef ENABLE_OPENGL
-  glViewport(m_renderSurf.upperleft().x, m_renderSurf.upperleft().y,
-	     m_renderSurf.size().x,      m_renderSurf.size().y);						 
+  glViewport(m_renderSurf.downleft().x, m_renderSurf.downleft().y,
+  	     m_renderSurf.size().x, m_renderSurf.size().y);
   glMatrixMode(GL_PROJECTION);
   glLoadIdentity();
   glMatrixMode(GL_MODELVIEW);
   glLoadIdentity();
 #endif
+
+  activate();
 }
 
-void Camera::setRenderSurface(Vector2i upperleft, Vector2i downright){
-  m_renderSurf.update(upperleft, downright);
+void Camera::setRenderSurface(Vector2i downleft, Vector2i upright){
+  m_renderSurf.update(downleft, upright);
 }
 
 bool Camera::isMirrored() {
@@ -715,15 +725,11 @@ float Camera::guessDesiredAngleRotation() {
 }
 
 Vector2i Camera::getDispBottomLeft() {
-  return Vector2i(m_renderSurf.upperleft().x, m_renderSurf.downright().y);
+  return m_renderSurf.downleft();
 }
 
-Vector2i Camera::getDispTopLeft() {
-  return m_renderSurf.upperleft();
-}
-
-Vector2i Camera::getDispBottomRight() {
-  return m_renderSurf.downright();
+Vector2i Camera::getDispUpRight() {
+  return m_renderSurf.upright();
 }
 
 void Camera::allowActiveZoom(bool i_value) {
@@ -732,10 +738,6 @@ void Camera::allowActiveZoom(bool i_value) {
   initZoom();
 }
 
-void Camera::allowTrailCam(bool i_value) {
-  m_useTrailCam = i_value;
-}
-
 void Camera::clearGhostsVisibility() {
   m_ghostVisibility.clear();
 }
@@ -772,3 +774,18 @@ bool Camera::isGhostIn(unsigned int i) {
   checkGhostVisibilityExists(i);
   return m_ghostVisibility[i].isIn;
 }
+
+float Camera::getShadeTime() {
+  return m_nShadeTime;
+}
+
+void Camera::setShadeTime(float i_time) {
+  m_nShadeTime = i_time;
+}
+
+void Camera::setScreenShade(bool i_doShade, bool i_doShadeAnim) 
+{ 
+  m_doShade = i_doShade; 
+  m_doShadeAnim = i_doShadeAnim; 
+}
+
