@@ -76,8 +76,6 @@ float ZonePrimBox::Bottom() const {
 
 Zone::Zone(const std::string& i_id) {
   m_id = i_id;
-  m_isDeathZone = false;
-  m_isTeleportZone = false;
 }
 
 Zone::~Zone() {
@@ -109,13 +107,15 @@ bool Zone::doesCircleTouch(const Vector2f& i_cp, float i_cr) {
   return false;
 }
 
-Zone* Zone::readFromXml(TiXmlElement *pElem) {
-  Zone *v_zone = new Zone(XML::getOption(pElem,"id"));
+Zone* Zone::readFromXml(xmlNodePtr pElem) {
+  Zone *v_zone = new Zone(XMLDocument::getOption(pElem, "id"));
   
   /* Get primitives */
-  for(TiXmlElement *pj = pElem->FirstChildElement("box"); pj!=NULL; pj=pj->NextSiblingElement("box")) {
-    v_zone->m_prims.push_back(ZonePrimBox::readFromXml(pj));
-  }  
+  for(xmlNodePtr pSubElem = XMLDocument::subElement(pElem, "box");
+      pSubElem != NULL;
+      pSubElem = XMLDocument::nextElement(pSubElem)) {
+	v_zone->m_prims.push_back(ZonePrimBox::readFromXml(pSubElem));
+  }
   
   return v_zone;
 }
@@ -129,58 +129,6 @@ void Zone::saveBinary(FileHandle *i_pfh) {
     Prims()[j]->saveBinary(i_pfh);
   }
 }
-
-void Zone::setDeathZone(bool i_value) {
-  m_isDeathZone = i_value;
-}
-
-bool Zone::isDeathZone() {
-  return m_isDeathZone;
-}
-
-void Zone::setTeleportZone(bool i_value) {
-  m_isTeleportZone = i_value;
-}
-
-bool Zone::isTeleportZone() {
-  return m_isTeleportZone;
-}
-
-void Zone::updateZoneSpeciality(std::string i_scriptSource) {
-  /* This function parses the Script Source for death zones: zones, 
-     that typically consist of OnEnter() and Game.KillPlayer() and end
-     AND
-     for teleport zones, using setPlayerPosition() function  */
-     
-  //determine the positions between special zone function start and end
-  std::string v_specialZoneFunctionString = m_id + ".OnEnter";  // includes also OnEnterBy()
-  size_t v_posStart = i_scriptSource.find(v_specialZoneFunctionString);
-  if(v_posStart == std::string::npos) {
-    //Zone isnt in the script? hum, strange but
-    return;
-  } 
-  size_t v_posEnd = i_scriptSource.find("end", v_posStart);
-
-  // check for deathzone
-  size_t v_found_death = i_scriptSource.find(".KillPlayer", v_posStart);
-  if(v_found_death == std::string::npos) {
-    v_found_death = i_scriptSource.find(".KillAPlayer", v_posStart);
-  }
-  if(v_found_death != std::string::npos && (v_found_death > v_posStart && v_found_death < v_posEnd)) {
-    //looks like we identified a death zone!
-    this->setDeathZone(true);
-    return;
-  }
-  // check for teleport zone
-  size_t v_found_teleport = i_scriptSource.find(".SetPlayerPosition", v_posStart);
-  if(v_found_teleport == std::string::npos) {
-    v_found_teleport = i_scriptSource.find(".SetAPlayerPosition", v_posStart);
-  }
-  if(v_found_teleport != std::string::npos && (v_found_teleport > v_posStart && v_found_teleport < v_posEnd)) {
-    //looks like we identified a teleport zone!
-    this->setTeleportZone(true);
-  }
-}
         
 void ZonePrimBox::saveBinary(FileHandle *i_pfh) {
   XMFS::writeFloat_LE(i_pfh,m_left);
@@ -208,13 +156,13 @@ Zone* Zone::readFromBinary(FileHandle *i_pfh) {
   return v_zone;
 }
 
-ZonePrim* ZonePrimBox::readFromXml(TiXmlElement *i_elem) {
+ZonePrim* ZonePrimBox::readFromXml(xmlNodePtr pElem) {
   float v_bottom, v_top, v_left, v_right;
 
-  v_bottom = atof( XML::getOption(i_elem,"bottom","0").c_str() );
-  v_top    = atof( XML::getOption(i_elem,"top","0").c_str() );
-  v_left   = atof( XML::getOption(i_elem,"left","0").c_str() );
-  v_right  = atof( XML::getOption(i_elem,"right","0").c_str() );
+  v_bottom = atof( XMLDocument::getOption(pElem,"bottom","0").c_str() );
+  v_top    = atof( XMLDocument::getOption(pElem,"top","0").c_str() );
+  v_left   = atof( XMLDocument::getOption(pElem,"left","0").c_str() );
+  v_right  = atof( XMLDocument::getOption(pElem,"right","0").c_str() );
   
   return new ZonePrimBox(v_left, v_right, v_top, v_bottom);
 }
